<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Addon;
use App\Models\AddonValue;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class AddonController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $addons = Addon::orderBy('id','DESC')->paginate(10);
            // foreach($addons as $addon){
            //     $values = AddonValue::where('addon_id',$addon->id)->get();
            //     $addNew[] = array(
            //         $addon,
            //         'values' => $values
            //     );
            // }
            return view('admin.addon.list', ['addons' => $addons]);
        }
        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.addon.create');
        }
        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_en' => 'required',
            'name_ar' => 'required',
            'input_type' => 'required',
         ]);

        $addon = new Addon;

        $addon->name_en = $request->name_en;
        $addon->name_ar = $request->name_ar;
        $addon->input_type = $request->input_type;
        $addon->minimum = ($request->minimum)?$request->minimum:0;
        $addon->maximum = ($request->maximum)?$request->maximum:0;
        $addon->save();

        foreach($request->value_en as $key=>$enval){
            $addonValue = new AddonValue;
            $addonValue->addon_id = $addon->id;
            $addonValue->name_en = $enval;
            $addonValue->name_ar = $request->value_ar[$key];
            $addonValue->price = $request->price[$key];
            $addonValue->price_type = $request->price_type[$key];
            $addonValue->operand = $request->operand[$key];
            $addonValue->visible = $request->show[$key];
            $addonValue->save();
        }

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Addon added successfully!');
        return redirect()->route('addon.list');
    }

    public function edit($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $addon = Addon::find($id);
        $values = AddonValue::where('addon_id', $id)->get();
        return view('admin.addon.update', ['addon' => $addon, 'values'=>$values]);
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');

        $validation = [
            'name_en' => 'required',
            'name_ar' => 'required',
            'input_type' => 'required',
        ];

        $request->validate($validation);

        $addon = Addon::find($id);

        $addon->name_en = $request->name_en;
        $addon->name_ar = $request->name_ar;
        $addon->input_type = $request->input_type;
        $addon->minimum = ($request->minimum)?$request->minimum:0;
        $addon->maximum = ($request->maximum)?$request->maximum:0;
        $addon->save();

        $requestIds = $request->ids;
        $ids = AddonValue::where('addon_id',$id)->get();
        foreach($ids as $id){
            if(!in_array($id->id, $requestIds)){
                AddonValue::find($id->id)->delete();
            }
        }
        foreach($request->value_en as $key=>$enval){
            if($request->ids[$key]!=NULL)
                $addonValue = AddonValue::find($request->ids[$key]);
            else
                $addonValue = new AddonValue;

            $addonValue->addon_id = $addon->id;
            $addonValue->name_en = $enval;
            $addonValue->name_ar = $request->value_ar[$key];
            $addonValue->price = $request->price[$key];
            $addonValue->price_type = $request->price_type[$key];
            $addonValue->operand = $request->operand[$key];
            $addonValue->visible = isset($request->show[$key])?$request->show[$key]:0;
            $addonValue->save();
        }

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Info updated successfully!');
        return redirect()->route('addon.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $addon = Addon::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Addon deleted successfully!');
        return redirect()->back();
    }
    public function addVDelete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $value = AddonValue::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Value deleted successfully!');
        return redirect()->back();
    }

}
