<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class BranchController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {

            $branches = Branch::orderBy('id','DESC')->paginate(10);
            return view('admin.branch.list', ['branches' => $branches]);
        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            $users = User::where('role','branch')->get();
            return view('admin.branch.create', ['users' => $users]);
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'name' => 'required|max:255|unique:branches,name',
            'phone' => 'required|max:8',
            'address' => 'required|min:10',//|confirmed
            'g_location' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
            'delivery_time' => 'required',
         ]);

        $branch = new Branch;

        $branch->name = $request->name;
        $branch->slug = Str::slug($request->name);
        $branch->phone = $request->phone;
        $branch->address = $request->address;
        $branch->g_location = $request->g_location;
        $branch->opening_time = $request->opening_time;
        $branch->closing_time = $request->closing_time;
        $branch->delivery_time = $request->delivery_time;
        $branch->pickup = ($request->pickup)?$request->pickup:0;
        $branch->store_busy = ($request->store_busy)?$request->store_busy:0;
        $branch->user_id = $request->user_id;
        $branch->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch added successfully!');
        return redirect()->route('branch.list');
    }

    public function edit($slug)
    {
        $branch = Branch::where('slug',$slug)->first();
        $users = User::where('role','branch')->get();
        return view('admin.branch.update', ['branch' => $branch, 'users' => $users]);
    }

    public function update(Request $request)
    {
        
        $branch = Branch::where('slug',$request->slug)->first();
        $validation = [
            // 'id' => 'required|exists:branchs,id',
            'user_id' => 'required|exists:users,id',
            'name' => 'required|max:255|unique:branches,name,'.$branch->id,
            'phone' => 'required|max:8',
            'address' => 'required|min:10',//|confirmed
            'g_location' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
            'delivery_time' => 'required',
        ];

        $request->validate($validation);


        $branch->name = $request->name;
        $branch->slug = Str::slug($request->name);
        $branch->phone = $request->phone;
        $branch->address = $request->address;
        $branch->g_location = $request->g_location;
        $branch->opening_time = $request->opening_time;
        $branch->closing_time = $request->closing_time;
        $branch->delivery_time = $request->delivery_time;
        $branch->pickup = ($request->pickup)?$request->pickup:0;
        $branch->store_busy = ($request->store_busy)?$request->store_busy:0;
        $branch->user_id = $request->user_id;
        $branch->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch updated successfully!');
        return redirect()->route('branch.list');
    }

    public function delete($slug)
    {
        $branch = Branch::where('slug',$slug)->delete();
        // $annualReport->isdeleted = '1';
        // $annualReport->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch deleted successfully!');
        return redirect()->back();
    }

}
