<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Coupon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class CouponController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $coupons = Coupon::orderBy('id','DESC')->paginate(10);
            return view('admin.coupon.list', ['coupons' => $coupons]);
        }
        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.coupon.create');
        }
        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'type' => 'required',
            'code' => 'required',
            'amount' => 'required',
            // 'start_date' => 'required',
            // 'end_date' => 'required',
         ]);

        $coupon = new Coupon;

        $coupon->type = $request->type;
        $coupon->code = $request->code;
        $coupon->amount = $request->amount;
        $coupon->quantity = ($request->quantity)?$request->quantity:0;
        $coupon->start_dt = ($request->start_date)?$request->start_date:'';
        $coupon->end_at = ($request->end_date)?$request->end_date:'';
        $coupon->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Coupon added successfully!');
        return redirect()->route('coupon.list');
    }

    public function edit($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $coupon = Coupon::find($id);
        return view('admin.coupon.update', ['coupon' => $coupon]);
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');

        $validation = [
            'type' => 'required',
            'code' => 'required',
            'amount' => 'required',
        ];

        $request->validate($validation);

        $coupon = Coupon::find($id);

        $coupon->type = $request->type;
        $coupon->code = $request->code;
        $coupon->amount = $request->amount;
        $coupon->quantity = ($request->quantity)?$request->quantity:0;
        $coupon->start_dt = ($request->start_date)?$request->start_date:'';
        $coupon->end_at = ($request->end_date)?$request->end_date:'';
        $coupon->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Coupon updated successfully!');
        return redirect()->route('coupon.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $coupon = Coupon::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Coupon deleted successfully!');
        return redirect()->back();
    }

}
