<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Review;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class ReviewController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $users = User::where('role', 'customer')->get();
            $products = Product::where('visible', 1)->get();
            $reviews = Review::join('users', 'users.id', '=', 'reviews.user_id')
                ->join('products', 'products.id', '=', 'reviews.product_id')
                ->select('reviews.*', 'users.name as user', 'products.name_en as product')
                ->orderBy('id','DESC')->paginate(10);
            return view('admin.review.list', ['reviews' => $reviews, 'users'=>$users, 'products'=>$products]);
        }
        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            $users = User::where('role', 'customer')->get();
            $products = Product::where('visible', 1)->get();
            return view('admin.review.create', ['users'=>$users, 'products'=>$products]);
        }
        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'user' => 'required',
            'review' => 'required',
            'rating' => 'required',
            'product' => 'required',
         ]);

        $review = new Review;

        $review->user_id = $request->user;
        $review->rating = $request->rating;
        $review->review = $request->review;
        $review->product_id = $request->product;
        $review->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Review added successfully!');
        return redirect()->route('review.list');
    }

    public function edit($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $users = User::where('role', 'customer')->get();
        $products = Product::where('visible', 1)->get();
        $review = Review::find($id);
        return view('admin.review.update', ['review' => $review, 'users'=>$users, 'products'=>$products]);
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');

        $validation = [
            'user' => 'required',
            'review' => 'required',
            'rating' => 'required',
            'product' => 'required',
        ];

        $request->validate($validation);

        $review = Review::find($id);

        $review->user_id = $request->user;
        $review->rating = $request->rating;
        $review->review = $request->review;
        $review->product_id = $request->product;
        $review->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Review updated successfully!');
        return redirect()->route('review.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $review = Review::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Review deleted successfully!');
        return redirect()->back();
    }

}
