<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Customer;
use App\Models\AddressBook;
use App\Models\Order;
use App\Models\CartItem;
use App\Models\Branch;
use App\Models\Area;
use App\Models\Timeslot;
use App\Models\Product;
use App\Models\Category;
use App\Models\Cart;
use App\Models\Addon;
use App\Models\AddonValue;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Builder;
use Auth;

class AccountController extends Controller
{

	public function __construct(){
		$this->user_id = 0;
		if(auth()->check()){
			$this->user_id = session('id');
		} else {
			return redirect()->route('home');
		}
	}

	public function index(){
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		$user['user']['addresses'] = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', $this->user_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->limit(2)->orderBy('id','DESC')->get();
		$area = Area::all();
		return view('frontend.dashboard', ['user'=>$user, 'areas'=>$area]);
	}

	public function myAccount(){
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		$user['user']['addresses'] = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', $this->user_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->limit(2)->orderBy('id','DESC')->get();
		$area = Area::all();
		return view('frontend.account-info', ['user'=>$user, 'areas'=>$area]);		
	}

	public function addressBook() {
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		$user['user']['addresses'] = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', $this->user_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->get();

		$area = Area::all();
		return view('frontend.saved-addresses', ['user'=>$user, 'areas'=>$area]);
	}

	public function addAddress(){
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		$user['user']['addresses'] = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', $this->user_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->get();
		$area = Area::all();
		return view('frontend.add-new-address', ['user'=>$user, 'areas'=>$area]);
	}

	public function addAddressStore(Request $request){
		
		$request->validate([
            'fname' => 'required|min:3',
            'phone' => 'required|min:8|max:8',
            'email' => 'required',
            'area' => 'required',
            'block' => 'required',
            'street' => 'required',
        ]);

        $address = new AddressBook;

        $address->name = $request->fname;
        $address->phone = $request->phone;
        $address->email = $request->email;
        $address->area = $request->area;
        $address->block = $request->block;
        $address->street = $request->street;
        $address->avenue = $request->avenue;
        $address->user_id = $this->user_id;
        $address->save();

        if($request->redirectTo)
        	return redirect($request->redirectTo);
        		
		return redirect()->route('address.book');
	}

	public function updateAddress(Request $request){
		$address = AddressBook::find($request->id);
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		// $user['user']['addresses'] = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', $this->user_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->get();
		$area = Area::all();
		return view('frontend.update-address', ['user'=>$user, 'address' => $address, 'areas'=>$area]);
	}

	public function updateAddressStore(Request $request){
		
		$request->validate([
            'fname' => 'required|min:3',
            'phone' => 'required|min:8|max:8',
            'email' => 'required',
            'area' => 'required',
            'block' => 'required',
            'street' => 'required',
        ]);

        $address = AddressBook::find($request->id);
        $address->name = $request->fname;
        $address->phone = $request->phone;
        $address->email = $request->email;
        $address->area = $request->area;
        $address->block = $request->block;
        $address->street = $request->street;
        $address->avenue = $request->avenue;
        // $address->user_id = $this->user_id;
        $address->save();

		return redirect()->route('address.book');
	}

	public function updateProfile(Request $request){

		$request->validate([
            'full_name' => 'required',
            'email' => 'required',
        ]);

		$user = User::find(session('id'));
		$user->name = $request->full_name;
		$user->email = $request->email;
		$user->save();

        $profile = Customer::where('user_id',session('id'))->first();
        if(!$profile){
        	$profile = new Customer;
        	$profile->user_id = $user->id;
        }
        $profile->phone = ($request->phone)?$request->phone:'';
        $profile->dob = ($request->date_of_birth)?$request->date_of_birth:'';
        $profile->save();
        return redirect()->route('my.account');
	}

	public function myOrders(){		
		$user['user'] = User::find($this->user_id);
		$user['user']['profile'] = Customer::where('user_id', $this->user_id)->first();
		$user['user']['orders'] = $this->getOrders();
		return view('frontend.my-orders', ['user'=>$user]);
	}

	public function getOrders(){
		$orders = Order::join('carts', 'carts.order_id', '=', 'orders.id')
			->where('orders.user_id', $this->user_id)
			->orderBy('id','DESC')
			->get(['orders.*', 'carts.id as cart_id', 'carts.subtotal', 'carts.delivery','carts.discount','carts.discount','carts.ip']);

		foreach($orders as $key=>$order){
			$allitems = CartItem::where('cart_id',$order->cart_id)->get();
			$items = [];
			foreach($allitems as $ikey=>$item){
				$branch = Branch::find($item->branch_id);
				$area = Area::find($item->area_id);
				$slot = Timeslot::find($item->slot);
				$product = Product::find($item->product_id);
				$addons = [];
				if($item->addon){
					$addonList = json_decode($item->addon, true);
					foreach($addonList as $akey=>$addon){
						$qty = $addon['qty'];
						$price = $addon['price'];
						$avalue = AddonValue::find($akey);
						$operand = $avalue->operand;
						$price_type = $avalue->price_type;
						$addonTotal[] = $addon['price']*$addon['qty'];
						$addons[] = array(
							'addon' => $avalue,
							'qty' => $qty,
							'price' => $price,
						);
					}
				}
				$items[$ikey] = $item;
				$items[$ikey]['product']=$product;
				$items[$ikey]['addons']=$addons;
				$items[$ikey]['branch']=$branch;
				$items[$ikey]['area']=$area;
				$items[$ikey]['slot']=$slot;
			}
			$gorder[$key] = $order;
			$gorder[$key]['items'] = $items;
		}
		// dump($gorder);die();
		return $gorder;
	}
}