<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Announcement;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class AnnouncementController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $announcements = Announcement::orderBy('id','DESC')->paginate(10);
            return view('admin.announcement.list', ['announcements' => $announcements]);
        }
        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.announcement.create');
        }
        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'text_en' => 'required',
            'text_ar' => 'required',
            'start_date' => 'required',
            'expiry_date' => 'required',
         ]);

        $info = new Announcement;

        $info->text_en = $request->text_en;
        $info->text_ar = $request->text_ar;
        $info->start_dt = date('Y-m-d h:i:s', strtotime($request->start_date));
        $info->expiry_dt = date('Y-m-d h:i:s', strtotime($request->expiry_date));
        $info->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Info added successfully!');
        return redirect()->route(session('role').'.announcement.list');
    }

    public function edit($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $announcement = Announcement::find($id);
        return view('admin.announcement.update', ['announcement' => $announcement]);
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');

        $validation = [
            'text_en' => 'required',
            'text_ar' => 'required',
            'start_date' => 'required',
            'expiry_date' => 'required',
        ];

        $request->validate($validation);

        $info = Announcement::find($id);

        $info->text_en = $request->text_en;
        $info->text_ar = $request->text_ar;        
        $info->start_dt = date('Y-m-d h:i:s', strtotime($request->start_date));
        $info->expiry_dt = date('Y-m-d h:i:s', strtotime($request->expiry_date));
        $info->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Info updated successfully!');
        return redirect()->route(session('role').'.announcement.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $announcement = Announcement::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Info deleted successfully!');
        return redirect()->back();
    }

}
