<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use App\Models\BranchExclude;
use App\Models\BranchPickup;
use App\Models\BranchArea;
use App\Models\State;
use App\Models\Area;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class BranchController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {

            $branches = Branch::orderBy('id','DESC')->paginate(10);
            return view('admin.branch.list', ['branches' => $branches]);
        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            $branches = Branch::all();
            foreach($branches as $branch){
                $ids[] = $branch->user_id;
            }
            $users = User::whereNotIn('id',$ids)->where('role','branch')->get();
            return view('admin.branch.create', ['users' => $users]);
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'name' => 'required|max:255|unique:branches,name',
            'phone' => 'required|max:8',
            'address' => 'required|min:10',//|confirmed
            'g_location' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
            'delivery_time' => 'required',
         ]);

        $branch = new Branch;
        $destinationPath = 'gallery/branch';

        $branch->name = $request->name;
        $branch->slug = Str::slug($request->name);
        $branch->phone = $request->phone;
        $branch->address = $request->address;
        $branch->g_location = $request->g_location;
        $branch->opening_time = $request->opening_time;
        $branch->closing_time = $request->closing_time;
        $branch->delivery_time = $request->delivery_time;
        $branch->pickup = ($request->pickup)?$request->pickup:0;
        $branch->store_busy = ($request->store_busy)?$request->store_busy:0;
        $branch->user_id = $request->user_id;
        if($thumbnail = $request->file('thumbnail')){
            $branch->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $branch->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch added successfully!');
        return redirect()->route(session('role').'.branch.list');
    }

    public function edit($slug)
    {
        $branch = Branch::where('slug',$slug)->first();
        $users = User::where('role','branch')->get();
        return view('admin.branch.update', ['branch' => $branch, 'users' => $users]);
    }

    public function update(Request $request)
    {        
        $branch = Branch::where('slug',$request->slug)->first();
        $validation = [
            // 'id' => 'required|exists:branchs,id',
            'user_id' => 'required|exists:users,id',
            'name' => 'required|max:255|unique:branches,name,'.$branch->id,
            'phone' => 'required|max:8',
            'address' => 'required|min:10',//|confirmed
            'g_location' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
            'delivery_time' => 'required',
        ];

        $request->validate($validation);

        $destinationPath = 'gallery/branch';

        $branch->name = $request->name;
        $branch->slug = Str::slug($request->name);
        $branch->phone = $request->phone;
        $branch->address = $request->address;
        $branch->g_location = $request->g_location;
        $branch->opening_time = $request->opening_time;
        $branch->closing_time = $request->closing_time;
        $branch->delivery_time = $request->delivery_time;
        $branch->pickup = ($request->pickup)?$request->pickup:0;
        $branch->store_busy = ($request->store_busy)?$request->store_busy:0;
        $branch->user_id = $request->user_id;
        if($thumbnail = $request->file('thumbnail')){
            $branch->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $branch->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch updated successfully!');
        return redirect()->route(session('role').'.branch.list');
    }

    public function delete($slug)
    {
        $branch = Branch::where('slug',$slug)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Branch deleted successfully!');
        return redirect()->back();
    }

    public function exclude($slug){
        $branch = Branch::where('slug',$slug)->first();
        $products = Product::where('visible',1)->get();
        $data = BranchExclude::where('branch_id',$branch->id)->first();
        $excluded = [];
        if($data){
            $excluded = json_decode($data->pid, true);
        }
        return view('admin.branch.exclude', ['branch' => $branch, 'products'=>$products, 'data'=>$excluded]); 
    }

    public function excludeProducts(Request $request){
        $branch = Branch::where('slug',$request->slug)->first();
        $exludes = BranchExclude::where('branch_id', $branch->id)->first();
        if(!$exludes){
            $excludes = new BranchExclude;
            $pids = json_encode($request->products);
        } else {
            $pids = json_decode($excludes->pid, true);
            $pids = json_encode(array_merge($pids, $request->products));
        }

        
        $excludes->branch_id = $branch->id;
        $excludes->pid = $pids;
        $excludes->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Data updated successfully!');
        return redirect()->route(session('role').'.branch.list'); 
    }

    public function excludePickup($slug){
        $branch = Branch::where('slug',$slug)->first();
        $products = Product::where('visible',1)->get();
        $data = BranchPickup::where('branch_id',$branch->id)->first();
        $excluded = [];
        if($data){
            $excluded = json_decode($data->pid, true);
        }
        return view('admin.branch.pickup', ['branch' => $branch, 'products'=>$products, 'data'=>$excluded]); 
    }

    public function addArea($slug){
        $branch = Branch::where('slug',$slug)->first();
        $states = State::all();
        $new = [];
        foreach($states as $state){
            $data = Area::where('state_id', $state->id)->get();
            $new[$state->id] = $state;
            $new[$state->id]['areas'] = $data;
        }
        $data = BranchArea::where('branch_id',$branch->id)->first();
        $areas = [];
        if($data){
            $areas = json_decode($data->area_id, true);
        }
        
        return view('admin.branch.area', ['branch' => $branch, 'states'=>$new, 'data'=>$areas]); 
    }

    public function excludePickupProducts(Request $request){
        $branch = Branch::where('slug',$request->slug)->first();
        $exludes = BranchPickup::where('branch_id', $branch->id)->first();
        if(!$exludes){
            $excludes = new BranchPickup;
            $pids = json_encode($request->products);
        } else {
            $pids = json_decode($excludes->pid, true);
            $pids = json_encode(array_merge($pids, $request->products));
        }
        
        $excludes->branch_id = $branch->id;
        $excludes->pid = $pids;
        $excludes->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Data updated successfully!');
        return redirect()->route(session('role').'.branch.list'); 
    }

    public function storeArea(Request $request){
        $branch = Branch::where('slug',$request->slug)->first();
        $states = $request->state;

        $areas = BranchArea::where('branch_id', $branch->id)->first();
        if(!$areas){
            $areas = new BranchArea;
            $areas->branch_id = $branch->id;
        }

        $areas->area_id = json_encode($request->areas);
        $areas->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Data updated successfully!');
        return redirect()->route(session('role').'.branch.list');
    }

}
