<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class CategoryController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $categories = Category::orderBy('id','DESC')->paginate(10);
            return view('admin.category.list', ['categories' => $categories]);

        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.category.create');
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_en' => 'required|min:3|max:255|unique:categories,name_en',
            // 'email' => 'required|unique:users|email:filter|max:255',
            // 'u_type' => 'required|max:10',
            // 'password' => 'required|min:6',//|confirmed
            // 'isactive' => 'required',            
        ]);

        $category = new Category;

        $destinationPath = 'gallery/category';

        $category->name_en = ($request->name_en)?$request->name_en:'';
        $category->name_ar = ($request->name_ar)?$request->name_ar:'';
        $category->slug = Str::slug($request->name_en);
        $category->active = ($request->active)?1:0;
        if($thumbnail = $request->file('thumbnail')){
            $category->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $category->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Category added successfully!');
        return redirect()->route(session('role').'.category.list');
    }

    public function edit($slug)
    {
        $category = Category::where('slug',$slug)->first();
        return view('admin.category.update', ['category' => $category]);
    }

    public function update(Request $request)
    {
        $category = Category::where('slug',$request->slug)->first();
        // var_dump($category);die();
        $validation = [
            'name_en' => 'required|min:3|max:255|unique:categories,name_en,'.$category->id,
        ];

        $request->validate($validation);

        $destinationPath = 'gallery/category';

        $category->name_en = ($request->name_en)?$request->name_en:'';
        $category->name_ar = ($request->name_ar)?$request->name_ar:'';
        $category->slug = Str::slug($request->name_en);
        $category->active = ($request->active)?1:0;
        if($thumbnail = $request->file('thumbnail')){
            $category->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $category->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Category updated successfully!');
        return redirect()->route(session('role').'.category.list');
    }

    public function delete($slug)
    {
        $category = Category::where('slug',$slug)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Category deleted successfully!');
        return redirect()->back();
    }

}
