<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Occasion;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class OccasionController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $occasions = Occasion::orderBy('id','DESC')->paginate(10);
            return view('admin.occasion.list', ['occasions' => $occasions]);

        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.occasion.create');
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_en' => 'required|min:3|max:255|unique:occasions,name_en',
            // 'email' => 'required|unique:users|email:filter|max:255',
            // 'u_type' => 'required|max:10',
            // 'password' => 'required|min:6',//|confirmed
            // 'isactive' => 'required',            
        ]);

        $occasion = new Occasion;

        $destinationPath = 'gallery/occasion';

        $occasion->name_en = ($request->name_en)?$request->name_en:'';
        $occasion->name_ar = ($request->name_ar)?$request->name_ar:'';
        $occasion->slug = Str::slug($request->name_en);
        $occasion->active = ($request->active)?1:0;
        if($thumbnail = $request->file('thumbnail')){
            $occasion->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $occasion->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Occasion added successfully!');
        return redirect()->route(session('role').'.occasion.list');
    }

    public function edit($slug)
    {
        $occasion = Occasion::where('slug',$slug)->first();
        return view('admin.occasion.update', ['occasion' => $occasion]);
    }

    public function update(Request $request)
    {
        $occasion = Occasion::where('slug',$request->slug)->first();
        // var_dump($occasion);die();
        $validation = [
            'name_en' => 'required|min:3|max:255|unique:occasions,name_en,'.$occasion->id,
        ];

        $request->validate($validation);

        $destinationPath = 'gallery/occasion';

        $occasion->name_en = ($request->name_en)?$request->name_en:'';
        $occasion->name_ar = ($request->name_ar)?$request->name_ar:'';
        $occasion->slug = Str::slug($request->name_en);
        $occasion->active = ($request->active)?1:0;
        if($thumbnail = $request->file('thumbnail')){
            $occasion->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
        }
        $occasion->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Occasion updated successfully!');
        return redirect()->route(session('role').'.occasion.list');
    }

    public function delete($slug)
    {
        $occasion = Occasion::where('slug',$slug)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Occasion deleted successfully!');
        return redirect()->back();
    }

}
