<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Order;
use App\Models\CartItem;
use App\Models\Branch;
use App\Models\Area;
use App\Models\Timeslot;
use App\Models\Product;
use App\Models\Category;
use App\Models\Cart;
use App\Models\Addon;
use App\Models\AddonValue;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class OrderController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            // $orders = Order::where('isdelete',0)->orderBy('id','DESC')->paginate(10);
            $orders = Order::join('carts', 'carts.order_id', '=', 'orders.id')
                ->where('orders.isdelete',0)
                ->select(['orders.*', 'carts.id as cart_id', 'carts.subtotal', 'carts.delivery','carts.discount','carts.discount','carts.ip'])
                ->orderBy('id','DESC')
                ->paginate(10);
        }elseif(session('role') == 'branch'){
            $branch = Branch::where('slug',session('branch'))->first();
            $cart_items = CartItem::where('branch_id', $branch->id)->get();
            $ids = [];
            foreach($cart_items as $item){
                if(!in_array($item->id, $ids)){
                    $ids[] = $item->id;
                }
            }

            $carts = Cart::whereIn('id', $ids)->whereNot('order_id', 0)->get();
            $orders = $oids = [];
            foreach($carts as $cart){
                $oids[] = $cart->order_id;
            }
            
            rsort($oids);
            // var_dump($oids);die();
            // $allorders = Order::where('isdelete',0)->orderBy('id','DESC')->paginate(10);
            // foreach($allorders as $order){
            //     $orders['order']=$order;
            //     $orders['cart'] = $cart;
            // }
            $orders = Order::query()
                ->join('carts', 'carts.order_id', '=', 'orders.id')
                ->where('isdelete',0)
                ->whereIn('orders.id', $oids)
                ->select(['orders.*', 'carts.id as cart_id', 'carts.subtotal', 'carts.delivery','carts.discount','carts.discount','carts.ip'])
                ->orderBy('orders.id','DESC')
                ->paginate(10);
        }
        return view('admin.order.list', ['orders' => $orders]);
        return redirect()->back();
    }

    public function showDeleted()
    {
        if (session('role') == 'admin' || session('role') == 'branch') {
            $orders = Order::where('isdelete',1)->orderBy('id','DESC')->paginate(10);
            return view('admin.order.deleted', ['orders' => $orders]);
        }
        return redirect()->back();
    }

    // public function create()
    // {
    //     if (session('role') == 'admin') {
    //         return view('admin.order.create');
    //     }

    //     return redirect()->back();
    // }

    // public function store(Request $request)
    // {
    //     $request->validate([
    //         'name_en' => 'required|min:3|max:255|unique:orders,name_en',
    //         // 'email' => 'required|unique:users|email:filter|max:255',
    //         // 'u_type' => 'required|max:10',
    //         // 'password' => 'required|min:6',//|confirmed
    //         // 'isactive' => 'required',            
    //     ]);

    //     $order = new Order;

    //     $destinationPath = 'gallery/order';

    //     $order->name_en = ($request->name_en)?$request->name_en:'';
    //     $order->name_ar = ($request->name_ar)?$request->name_ar:'';
    //     $order->slug = Str::slug($request->name_en);
    //     $order->active = ($request->active)?1:0;
    //     if($thumbnail = $request->file('thumbnail')){
    //         $order->thumbnail = $thumbnail->getClientOriginalName();
    //         $thumbnail->move($destinationPath, $thumbnail->getClientOriginalName());
    //     }
    //     $order->save();
    //     session()->flash('alert-class', 'alert-success');
    //     session()->flash('alert-msg', 'Order added successfully!');
    //     return redirect()->route('order.list');
    // }

    public function view($id)
    {
        $order = $this->getSingleOrder($id);
        return view('admin.order.view', ['order' => $order]);
    }

    // public function edit($slug)
    // {
    //     $order = Order::where('slug',$slug)->first();
    //     return view('admin.order.update', ['order' => $order]);
    // }

    public function update(Request $request)
    {
        $order = Order::find($request->id);

        $order->pay_status = $request->pay_status;
        $order->status = $request->status;
        $order->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Order updated successfully!');
        return redirect()->route(session('role').'.order.list');
    }

    public function delete($id)
    {
        $order = Order::find($id);
        $order->isdelete = 1;
        $order->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Order deleted successfully!');
        return redirect()->back();
    }

    public function getSingleOrder($id){
        $order = Order::find($id);
        $cart = Cart::where('order_id', $id)->first();
        $allitems = CartItem::where('cart_id', $cart->id)->get();
        if(session('branch')){
            $branch = Branch::where('slug', session('branch'))->first();
            $allitems = CartItem::where('cart_id',$cart->id)->where('branch_id',$branch->id)->get();
        }

        $items = [];
        foreach($allitems as $ikey=>$item){
            $branch = Branch::find($item->branch_id);
            $area = Area::find($item->area_id);
            $slot = Timeslot::find($item->slot);
            $product = Product::find($item->product_id);
            $addons = [];
            if($item->addon){
                $addonList = json_decode($item->addon, true);
                foreach($addonList as $akey=>$addon){
                    $qty = $addon['qty'];
                    $price = $addon['price'];
                    $avalue = AddonValue::find($akey);
                    $operand = $avalue->operand;
                    $price_type = $avalue->price_type;
                    $addonTotal[] = $addon['price']*$addon['qty'];
                    $addons[] = array(
                        'addon' => $avalue,
                        'qty' => $qty,
                        'price' => $price,
                    );
                }
            }
            $items[$ikey] = $item;
            $items[$ikey]['product']=$product;
            $items[$ikey]['addons']=$addons;
            $items[$ikey]['branch']=$branch;
            $items[$ikey]['area']=$area;
            $items[$ikey]['slot']=$slot;
        }
        $gorder['order'] = $order;
        $gorder['cart'] = $cart;
        $gorder['items'] = $items;
        return $gorder;
    }

}
