<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use App\Models\Category;
use App\Models\Occasion;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class ProductController extends Controller
{

    public function index()
    {
        // var_dump(session()->all());die();
        if (session('role') == 'admin') {
            $products = Product::join('categories', 'categories.id', '=', 'products.category_id')->select('products.*', 'categories.name_en as cat_en','categories.name_ar as cat_ar')->orderBy('id','DESC')->paginate(10);
            return view('admin.product.list', ['products' => $products]);
        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            $categories = Category::all();
            $occasions = Occasion::all();
            return view('admin.product.create', ['categories' => $categories, 'occasions' => $occasions]);
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        // var_dump($request->all());die();
        $request->validate([
            'name_en' => 'required|min:3|max:255|unique:products,name_en',
            'description_en' => 'required|min:3',
            // 'quantity' => 'required',
            // 'price' => 'required',
            'category_id' => 'required',//|exists:categories,id
            'thumbnail' => 'required|file|mimes:jpg,png',
            'video' => 'sometimes|file|mimes:mp4,mpeg'
        ]);

        $product = new Product;

        $destinationPath = 'gallery/products';

        $product->name_en = $request->name_en;
        $product->name_ar = $request->name_ar;
        $product->slug = Str::slug($request->name_en);
        $product->description_en = $request->description_en;
        $product->description_ar = $request->description_ar;
        $product->quantity = json_encode($request->quantity);
        $product->preparation_time = $request->preparation_time;
        
        $product->dprice = min($request->price);
        $product->dsale_price = min($request->sale_price);

        $product->price = json_encode($request->price);
        $product->sale_price = json_encode($request->sale_price);
        $product->category_id = (int)$request->category_id;
        $product->occasion_id = (int)$request->occasion_id;
        $product->measurements = json_encode($request->weights);
        $product->new = ($request->new)?1:0;
        $product->preorder = ($request->preorder)?1:0;
        $product->visible = ($request->visible)?1:0;
        if($video = $request->file('video')){
            $product->video = $video->getClientOriginalName();
            $video->move($destinationPath.'/videos', $video->getClientOriginalName());
        }
        if($thumbnail = $request->file('thumbnail')){
            $product->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath.'/images', $thumbnail->getClientOriginalName());
        }
        if($gallery = $request->file('gallery')){
            // $gallery = $request->file('gallery');
            foreach($gallery as $img){
                $filename[] = $img->getClientOriginalName();
                $img->move($destinationPath.'/images', $img->getClientOriginalName());
            }
            $product->gallery = implode(',', $filename);
        }
        $product->save();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Product added successfully!');
        return redirect()->route(session('role').'.product.list');
    }

    public function edit($slug)
    {
        $product = Product::where('slug', $slug)->first();
        $categories = Category::all();
        $occasions = Occasion::all();
        return view('admin.product.update', ['product' => $product, 'categories'=>$categories, 'occasions'=>$occasions]);
    }

    public function update(Request $request)
    {
        $product = Product::where('slug', $request->slug)->first();
        $validation = [
            'name_en' => 'required|min:3|max:255|unique:products,name_en,'.$product->id,
            'description_en' => 'required|min:3',
            // 'quantity' => 'required',
            // 'price' => 'required',
            // 'category_id' => 'required|exists:categories,id',
            'video' => 'sometimes|file|mimes:mp4,mpeg'
        ];

        $request->validate($validation);

        $destinationPath = 'gallery/products';
        $product->name_en = $request->name_en;
        $product->name_ar = $request->name_ar;
        $product->slug = Str::slug($request->name_en);
        $product->description_en = $request->description_en;
        $product->description_ar = $request->description_ar;
        $product->quantity = json_encode($request->quantity);
        $product->preparation_time = $request->preparation_time;

        $product->dprice = min($request->price);
        $product->dsale_price = min($request->sale_price);
        
        $product->price = json_encode($request->price);
        $product->sale_price = json_encode($request->sale_price);
        $product->category_id = (int)$request->category_id;
        $product->occasion_id = (int)$request->occasion_id;
        $product->measurements = json_encode($request->weights);
        $product->new = ($request->new)?1:0;
        $product->preorder = ($request->preorder)?1:0;
        $product->visible = ($request->visible)?1:0;
        if($video = $request->file('video')){
            $product->video = $video->getClientOriginalName();
            $video->move($destinationPath.'/videos', $video->getClientOriginalName());
        }
        if($thumbnail = $request->file('thumbnail')){
            $product->thumbnail = $thumbnail->getClientOriginalName();
            $thumbnail->move($destinationPath.'/images', $thumbnail->getClientOriginalName());
        }
        if($gallery = $request->file('gallery')){

            $filename = ($product->gallery)?explode(',', $product->gallery):[];
            // $gallery = $request->file('gallery');
            foreach($gallery as $img){
                $filename[] = $img->getClientOriginalName();
                $img->move($destinationPath.'/images', $img->getClientOriginalName());
            }
            $filename = array_filter($filename);
            $product->gallery = implode(',', $filename);
        }
        $product->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Product updated successfully!');
        return redirect()->route(session('role').'.product.list');
    }

    public function delete($slug)
    {
        $product = Product::where('slug',$slug)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Product deleted successfully!');
        return redirect()->back();
    }

}
