<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use App\Models\State;
use App\Models\Area;
use App\Models\Timeslot;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class SettingController extends Controller
{

    public function indexState()
    {
        if (session('role') == 'admin') {
            $states = State::all();
            return view('admin.state.list', ['states' => $states]);

        }

        return redirect()->back();
    }

    public function createState()
    {
        if (session('role') == 'admin') {
            return view('admin.state.create');
        }
        return redirect()->back();
    }

    public function storeState(Request $request)
    {
        $request->validate([
            'name_en' => 'required|min:3|max:255',
            'name_ar' => 'required|min:3|max:255',          
        ]);

        $state = new State;

        $state->name_en = ($request->name_en)?$request->name_en:'';
        $state->name_ar = ($request->name_ar)?$request->name_ar:'';
        $state->save();
        
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'State added successfully!');
        return redirect()->route(session('role').'.setting.state.list');
    }

    public function editState($id)
    {
        $state = State::find($id);
        return view('admin.state.update', ['state' => $state]);
    }

    public function updateState(Request $request)
    {
        $validation = [
            'name_en' => 'required|min:3|max:255',
            'name_ar' => 'required|min:3|max:255',
        ];

        $request->validate($validation);

        $state = State::find($request->id);
        $state->name_en = ($request->name_en)?$request->name_en:'';
        $state->name_ar = ($request->name_ar)?$request->name_ar:'';
        $state->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'State updated successfully!');
        return redirect()->route(session('role').'.setting.state.list');
    }

    public function deleteState($id)
    {
        $state = State::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'State deleted successfully!');
        return redirect()->back();
    }

    public function indexArea()
    {
        if (session('role') == 'admin') {
            $areas = Area::join('states', 'states.id', '=', 'areas.state_id')->select('areas.*','states.name_en as state')->get();
            return view('admin.area.list', ['areas' => $areas]);

        }

        return redirect()->back();
    }

    public function createArea()
    {
        if (session('role') == 'admin') {
            $state = State::all();
            return view('admin.area.create',['states'=>$state]);
        }
        return redirect()->back();
    }

    public function storeArea(Request $request)
    {
        $request->validate([
            'state' => 'required',
            'name_en' => 'required|min:3|max:255',
            'name_ar' => 'required|min:3|max:255',          
        ]);

        $area = new Area;

        $area->state_id = $request->state;
        $area->name_en = ($request->name_en)?$request->name_en:'';
        $area->name_ar = ($request->name_ar)?$request->name_ar:'';
        $area->save();
        
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Area added successfully!');
        return redirect()->route(session('role').'.setting.area.list');
    }

    public function editArea($id)
    {
        $area = Area::find($id);
        $state = State::all();
        return view('admin.area.update', ['area' => $area, 'states'=>$state]);
    }

    public function updateArea(Request $request)
    {
        $validation = [
            'state' => 'required',
            'name_en' => 'required|min:3|max:255',
            'name_ar' => 'required|min:3|max:255',
        ];

        $request->validate($validation);

        $area = Area::find($request->id);
        $area->state_id = $request->state;
        $area->name_en = ($request->name_en)?$request->name_en:'';
        $area->name_ar = ($request->name_ar)?$request->name_ar:'';
        $area->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Area updated successfully!');
        return redirect()->route(session('role').'.setting.area.list');
    }

    public function deleteArea($id)
    {
        $area = Area::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Area deleted successfully!');
        return redirect()->back();
    }

    public function timeSlot($slug)
    {
        $role = auth()->user()->role;
        if (session('role') == 'admin' || session('role')=='branch') {
            $branch = Branch::where('slug', $slug)->first();
            $slots = Timeslot::where('branch_id', $branch->id)->get();
            return view('admin.branch.timeslot', ['slots'=>$slots, 'branch'=>$branch]);
        }
        return redirect()->back();
    }

    public function timeSlotStore(Request $request)
    {
        $branch = Branch::where('slug', $request->slug)->first();
        $rows = $request->row;
        $minimum_time = $request->minimum_time;
        $calendar_limit = $request->calendar_limit;
        $slots = Timeslot::where('branch_id', $branch->id)->get();
        $old=$new=[];
        foreach($slots as $slot){
            // $old[] = $slot->id;
        }

        foreach($rows as $row){
            if(array_key_exists('id', $row)){
                // $new[] = $row['id'];
                $time = Timeslot::find($row['id']);
            } else{
                $time = new Timeslot;
                $time->branch_id = $branch->id;
            }

            if(!array_key_exists('day', $row)){
                $time->delete();
                continue;
            }

            $time->minimum_time = $minimum_time;
            $time->calendar_limit = $calendar_limit;
            $time->day = $row['day'];
            $time->start = $row['start'];
            $time->end = $row['end'];
            $time->show = (array_key_exists('show', $row))?1:0;
            $time->save();
        }

        session()->flash('alert-msg', 'Slot updated successfully!');
        return redirect()->route(session('role').'.setting.timeslot',['slug'=>$request->slug]);
    }

}
