<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class UserController extends Controller
{

    public function index()
    {
        if (session('role') == 'admin') {
            $users = User::orderBy('id','DESC')->paginate(10);
            return view('admin.user.list', ['users' => $users]);
        }

        return redirect()->back();
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.user.create');
        }

        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|min:3|max:255',
            'email' => 'required|unique:users|email:filter|max:255',
            'role' => 'required|max:10',
            'password' => 'required|min:6',//|confirmed
            // 'isactive' => 'required',            
        ]);

        $user = new User;

        $user->name = $request->name;
        // $user->last_name = $request->last_name;
        $user->email = $request->email;
        // $user->username = $request->email;
        // $user->phone = $request->phone;
        $user->role = $request->role;
        $user->isactive = $request->isactive;
        $user->password = Hash::make($request->password);
        $user->remember_token = Hash::make(Str::random(32));
        $user->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'User registered successfully!');
        return redirect()->back();
    }

    public function edit($id)
    {
        // $id = (session('role') == 'admin') ? $id : session('id');
        if((session('role') == 'admin') || $id == session('id')){
            $user = User::find($id);
            return view('admin.user.edit', ['user'=>$user]);
        }
        return redirect()->back();
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');
        if (session('role') == 'branch') {
            $validation['name'] = 'required|min:3|max:255';
        } else {
            $validation = [
                'name' => 'required|min:3|max:255',
                'role' => 'sometimes|required|max:10',            
            ];
        }

        if ($request->password != '') {
            $validation['password'] = 'required|min:6';
        }

        $request->validate($validation);

        $user = User::find($id);
        $user->name = $request->name;
        // $user->last_name = $request->last_name;
        // $user->phone = $request->phone;

        
        if (session('role') == 'admin') {
            $user->role = $request->role;
            $user->isactive = ($request->isactive)?$request->isactive:0;
        }

        if ($request->password != '') {
            $user->password = Hash::make($request->password);
        }
        
        $user->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'User updated successfully!');
        if (session('role') == 'branch') 
            return redirect()->back();
        else    
            return redirect()->route(session('role').'.user.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $annualReport = User::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'User deleted successfully!');
        return redirect()->back();
    }

}
