<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Cart;
use App\Models\Branch;
use App\Models\Customer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Session;

class AuthenticationController extends Controller
{
    public function login()
    {
        if(Auth::check()){
            return redirect()->route(session('role').'.dashboard');
        }
        return view('admin.login');
    }

    public function loginSubmit(Request $request)
    {
        // $validation = validator()->make($request->all(), [
        session()->put('backpage','login');
        $request->validate([
            'email' => 'required|exists:users,email',
            'password' => 'required'
        ]);

        // if ($validation->fails()) {
        //     return redirect()->back()->with('login-error', $validation->errors()->first());
        //     // return response()->json(['message' => $validation->errors()->first(), 'status' => 'error'], 401);
        // }
        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            session()->forget('backpage');
            // var_dump(session('cart_id'));
            $user = Auth::user();
            if($user->role == 'branch'){
                $branch = Branch::where('user_id', $user->id)->first();
                session()->put('branch',$branch->slug);
                session()->put('branch_id',$branch->id);
            }
            $request->session()->regenerate();
            $s_user = json_decode($user, true);
            foreach($s_user as $key=>$val){
                session()->put($key, $val);
            }

            //update cart user
            // var_dump(session('cart_id'));
            if(session('cart_id')){
                $cart = Cart::find(session('cart_id'));
                $cart->user_id = $user->id;
                $cart->save();
            }

            if($user->role == 'customer' || array_key_exists('redirectTo', $request->all())){
                return redirect()->back();//route($request->redirectTo);
            }
            return redirect()->route($user->role.'.dashboard');            
        }
        
        session()->flash('login_status', 'Incorrect username or password');
        return redirect()->back();        
    }

    public function logout()
    {
        $url = session('_previous')['url'];
        $customer = '';
        if(strpos($url, 'admin')===false){
            $customer = true;
        }
        
        Auth::logout();
        session()->flush();
        session()->flash('login_status', 'Logged out successfully!');
        if($customer){
            session()->flash('backpage', 'login');
            return redirect()->route('home');    
        }
        return redirect()->route('login');
    }

    public function register(Request $request){
        session()->put('backpage','register');
        $request->validate([
            'full_name' => 'required|min:3|max:255',
            'email' => 'required|unique:users|email:filter|max:255',
            'password' => 'required|min:6|confirmed',
            'phone' => 'required|min:8|max:8',
        ]);

        $user = new User;
        $user->name = $request->full_name;
        $user->email = $request->email;
        $user->role = 'customer';
        $user->isactive = 1;
        $user->password = Hash::make($request->password);
        $user->remember_token = Hash::make(Str::random(32));
        $user->save();

        $customer = new Customer;
        $customer->user_id = $user->id;
        $customer->phone = $request->phone;
        $customer->dob = $request->date_of_birth;
        $customer->join_mail = (array_key_exists('join_mail', $request->all())) ? 1 : 0;
        $customer->save();
        
        // AUTO LOGIN
        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            session()->forget('backpage');
            $user = Auth::user();
            $request->session()->regenerate();
            $s_user = json_decode($user, true);
            foreach($s_user as $key=>$val){
                session()->put($key, $val);
            }            
            return redirect()->route('user.dashboard');
            // return ['body' => ['id' => $user->id, 'auth_token' => $user->remember_token, 'name' => $user->name, 'email' => $user->email], 'status' => 'successfull'];
        }

    }

    
}