<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use App\Models\Area;
use App\Models\Timeslot;
use App\Models\Product;
use App\Models\AddressBook;
use App\Models\Category;
use App\Models\Cart;
use App\Models\Coupon;
use App\Models\CartItem;
use App\Models\Addon;
use App\Models\AddonValue;
use App\Models\Order;
use App\Models\GuestUser;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Builder;

class CartController extends Controller
{
	public function __contruct(){

	}

	public function index(Request $request){
		$cart = json_decode($this->getCart(), true);
		return view('frontend.cart', ['cart'=>$cart]);//, 'total' => array_sum($total)]);
	}

	public function guestCheckout(Request $request){
		if(auth()->user() && request()->is('guest.checkout')){
			return redirect()->route('checkout');
		}
		$areas = Area::all();
		session()->put('backpage','guest-checkout');
		$request->validate([
            'full_name' => 'required|min:3|max:255',
            'email' => 'required|unique:users|email',
            'phone' => 'required|min:8|max:8',
        ]);
        session()->forget('backpage');
		session()->put('guest',$request->all());
		
		$cart_id = session('cart_id');
		$guest = GuestUser::where('email', $request->email)->orderBy('id', 'DESC')->first();
		if($guest) {
			$cart = Cart::find($guest->cart_id);
			if($cart->order_id==0 && $cart->user_id==0){
				$cart_id = $cart->id;
			}
		}
		if(!$guest)
			$guest = new GuestUser;

		$guest->cart_id = $cart_id;
		$guest->name = $request->full_name;
		$guest->email = $request->email;
		$guest->phone = $request->phone;
		$guest->save();

		$cart = json_decode($this->getCart(), true);
		return view('frontend.guest-checkout', ['cart'=>$cart, 'areas'=>$areas]);
	}

	public function guestCheckoutOpen(Request $request){
		$cart = json_decode($this->getCart(), true);
		$areas = Area::all();
		return view('frontend.guest-checkout', ['cart'=>$cart, 'areas'=>$areas]);
	}

	public function addToCart(Request $request){
		// var_dump($request->all());die();
		$request->validate([
        	'deliveryType' => 'required',
       	]);
		if($request->deliveryType == 'Pickup'){
			$request->validate([
	        	'branch' => 'required',
	       	]);
		} else {
			$request->validate([
	        	'del_date' => 'required',
	           	'area' => 'required',
	           	'slot' => 'required',
	       	]);
		}
		
		session()->put('deliveryType', $request->deliveryType);
		if($request->deliveryType == 'Pickup'){
			session()->put('sel-branch', $request->branch);
		} else {
			session()->put('sel-date', $request->del_date);
			session()->put('sel-area', $request->area);
			session()->put('sel-slot', $request->slot);
		}
		

   		// CART ITEM
		$product_id = $request->product_id;
		$weight = $request->weight;
		$branch_id = $request->branch_id;
		$area = $request->area;
		$delivery_date = $request->del_date; // FORMAT: 'm/d/Y'
		$input_del_date = $request->input_del_date;
		$deliveryType = $request->deliveryType;

		if(!empty($input_del_date))
			$delivery_date = $input_del_date;
		
		$slot = $request->slot;

		if($deliveryType == 'Pickup'){
			$branch_id = $request->branch;
			$area = NULL;
			$delivery_date = NULL;
			$slot = NULL;
		}
		$quantity = $request->quantity;
		$message = $request->message;
		$price = $request->price;
		$nadd = [];
		$addonTotal=[];
		if(array_key_exists('addon', $request->all())){
			$addons = $request->addon;
			foreach($addons as $addon){
				$add['qty'] = $request->qty[$addon];
				$add['price'] = $request->amount[$addon];
				$addonTotal[] = $add['qty']*$add['price'];
				$nadd[$addon] =$add;
			}
		}
		// CART ITEM END
		// CART
		$user_id = 0;
		$total = $quantity*$price;
		$total = $total + array_sum($addonTotal);
		$ip = static::get_client_ip();

		if(auth()->check()){
			$user_id = session('id');
			$cart = Cart::where('order_id',0)->where('user_id', $user_id)->first();
		} else {
			$cart = Cart::find(session('cart_id'));
		}
		if($cart){
			$cartItem = CartItem::query()
				->where('product_id', $product_id)
				->where('weight', $weight)
				->where('cart_id',$cart->id)
				->first();
			if(!$cartItem){
				$cartItem = new CartItem;
			}
		} else {
			$cart = new Cart;
			$cartItem = new CartItem;
		}

		$cart->user_id = $user_id;
		$cart->subtotal = $total;
		$cart->ip = $ip;
		// $cart->delivery = '';
		// $cart->discount = '';
		$cart->save();

		$cartItem->cart_id = $cart->id;
		$cartItem->product_id = $product_id;
		$cartItem->weight = $weight;
		$cartItem->quantity = (int)$cartItem->quantity + (int)$quantity;
		$cartItem->deliveryType = $deliveryType;
		$cartItem->branch_id = $branch_id;
		$cartItem->area_id = $area;
		$cartItem->delivery_date = $delivery_date;
		$cartItem->slot = $slot;
		$cartItem->message = $message;
		$cartItem->price = $price;
		if(count($nadd))
			$cartItem->addon = json_encode($nadd);
		$cartItem->save();
		
		session()->put('cart_id', $cart->id);
		session()->flash('backpage', 'addtocart');
		
		$this->updateAmount($cart->id);
		
		$cartCount = CartItem::query()
			->where('cart_id', $cart->id)
			->get()->count();
		
		session()->put('cartCount',$cartCount);
		session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Product added successfully!');
   		return redirect()->back()->with(['cart-count'=>$cartCount]);
	}

	public function getCartCount(){
		$count = 0;
		if(session('cart_id')){
			$count = CartItem::query()
				->where('cart_id', $cart->id)
				->get()->count();
		}
		return $count;
	}

	public function updateCart(Request $request){
		$quantity = $request->quantity;
		$qty = $request->qty;		
		foreach($quantity as $ikey=>$quant){
			$item = CartItem::find($ikey);
			$item->quantity = $quant;
			// var_dump($ikey);
			// var_dump($qty);
			// var_dump(array_key_exists($ikey, $qty));die();
			if($qty){
				if(array_key_exists($ikey, $qty)){
					$addon = json_decode($item->addon, true);
					foreach($addon as $k => $add){
						if(array_key_exists($k, $qty[$ikey])){
							$addon[$k]['qty'] = $qty[$ikey][$k];
						}
					}
					$addon = json_encode($addon);
					$item->addon = $addon;
				}
			}
			$item->save();
			$cart_id = $item->cart_id;
		}
		$this->updateAmount($cart_id);
		return redirect()->route('cart');
	}

	public function deleteCart($id){
		$cart = CartItem::find($id);
		$cart->delete();
		$this->updateAmount($cart->cart_id);
		return redirect()->route('cart');
	}

	public function removeCartItems(Request $request){
		$cart = CartItem::where('cart_id', session('cart_id'))->delete();
		$name = $request->name;
		$value = $request->val;
		if($name == 'deliveryType'){
			session()->put('deliveryType', $value);
			session()->forget('sel-branch');
			session()->forget('sel-area');
			session()->forget('sel-date');
			session()->forget('sel-slot');
		} elseif($name == 'area'){
			session()->put('sel-area', $value);
			session()->forget('sel-branch');
		} elseif($name == 'branch'){
			session()->put('sel-branch', $value);
			session()->forget('sel-area');
		}
		return response()->json(['result'=>'true']);
	}

	public function deleteAddonCart($id,$addonid){
		$cart = CartItem::find($id);
		$addons = json_decode($cart->addon, true);
		unset($addons[$addonid]);
		$cart->addon = json_encode($addons);
		$cart->save();
		$this->updateAmount($cart->cart_id);
		return redirect()->route('cart');
	}

	public function checkout(){
		$cart = json_decode($this->getCart(), true);
		$addresses = [];
		if(auth()->check()) {
			$addresses = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('user_id', session('id'))->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->get();	
		}
		$areas = Area::all();
        return view('frontend.checkout', ['addresses' => $addresses, 'cart'=>$cart, 'areas' =>$areas]);
    }

    public function pickup(){
    	$cart = json_decode($this->getCart(), true);
    	// var_dump($cart['cart']);die();
    	$branches = Branch::where('pickup',1)->where('store_busy',0)->get();
    	if(count($cart['cart']))
        	return view('frontend.pickup', ['branches'=>$branches, 'cart'=>$cart]);
        else
        	return redirect(route('products'));
    }

    public function payment(Request $request){
    	$cart = json_decode($this->getCart(), true);
    	$add['address_id'] = $request->address;
    	$add['billing_opt'] = ($request->billing_opt)?$request->billing_opt:0;
    	if($add['billing_opt'] || (session()->has('guest'))){
    		$add['name'] = $request->billing_name;
    		$add['phone'] = $request->billing_phone;
    		$add['email'] = $request->billing_email;
    		$add['block'] = $request->billing_block;
    		$add['street'] = $request->billing_street;
    		$add['area'] = $request->billing_area;
    		$add['avenue'] = $request->billing_avenue;
    	} elseif($request->type=='pickup'){
    		$add['name'] = $request->billing_name;
    		$add['phone'] = $request->billing_phone;
    		$add['email'] = $request->billing_email;
    		$add['type'] = $request->type;
    		$add['branch_id'] = $request->branch_id;
    		$branch = Branch::find($request->branch_id);
    		$add['branch'] = $branch->name;
    		$add['pickup_time'] = $request->pickup_time;
    	} else {
    		$address = AddressBook::find($add['address_id']);
    		$add['name'] = $address->name;
    		$add['phone'] = $address->phone;
    		$add['email'] = $address->email;
    		$add['block'] = $address->block;
    		$add['street'] = $address->street;
    		$add['area'] = $address->area;
    		$add['avenue'] = $address->avenue;
    	}
    	session()->put('cart-address', $request->all());
    	session()->put('cart-data', $add);
        return view('frontend.payment', ['address' => $add, 'cart'=>$cart]);

    	// $checkout = Order::where('user_id',session('id'))->where('status','not paid')->first();
		// $addresses = [];
		// if(auth()->check()) {
		// 	$addresses = AddressBook::where('user_id',session('id'))->get();			
		// }
    }

    public function placeOrder(Request $request){
    	$data = session('cart-data');
    	$address_id = ($data['address_id'])?$data['address_id']:0;
    	$billing_opt = ($data['billing_opt'])?$data['billing_opt']:0;
    	$block = '';
		$street = '';
		$area = '';
		$avenue = '';
    	if($billing_opt || (session()->has('guest'))){
    		$name = $data['name'];
    		$phone = $data['phone'];
    		$email = $data['email'];
    		$block = $data['block'];
    		$street = $data['street'];
    		$area = $data['area'];
    		$avenue = $data['avenue'];
    	} elseif(array_key_exists('type', $data) && $data['type']=='pickup'){
    		$name = $data['name'];
    		$phone = $data['phone'];
    		$email = $data['email'];
    		$type = $data['type'];
    		$branch_id = $data['branch_id'];
    		$pickup_time = $data['pickup_time'];
    	} else {
    		$address = AddressBook::find($address_id);
    		$name = $address->name;
    		$phone = $address->phone;
    		$email = $address->email;
    		$block = $address->block;
    		$street = $address->street;
    		$area = $address->area;
    		$avenue = $address->avenue;
    	}    	

    	$pay_type = $request->payment;

    	// $order = Order::where('user_id',session('id'))->where('status','unpaid')->first();
    	// if(!$order){
    		$order = new Order;
    		$order->user_id = (auth()->user()) ? session('id') : 0;
    	// }
    	if((array_key_exists('type', $data)) && $data['type']=='pickup'){
    		$order->type = 'pickup';
    		$order->branch_id = $branch_id;
    		$order->pickup_time = $pickup_time;
    	}
    	$order->address_id = $address_id;
    	$order->billing_opt = $billing_opt;
    	$order->billing_name = $name;
    	$order->billing_email = $email;
    	$order->billing_phone = $phone;
    	$order->billing_block = $block;
    	$order->billing_area = $area;
    	$order->billing_avenue = $avenue;
    	$order->billing_street = $street;
    	$order->pay_type = $pay_type;
    	if($pay_type == 'cod'){
	    	$order->status = 'confirm';
	    	$order->pay_status = 'unpaid';
	    	// $payment_url = route('confirm');
    	} elseif($pay_type == 'knet'){
    		$order->status = 'pending';
    		$order->pay_status = 'unpaid';
    	} elseif($pay_type == 'credit_card'){
    		$order->status = 'pending';
    		$order->pay_status = 'unpaid';
    	}
    	$order->save();
    	if($pay_type != 'cod'){
    		$payment_url = $this->payment_link($order->id, $pay_type);
    	} else {
    		$payment_url = route('order.confirm', ['id'=> $order->id]);
    	}
	    return redirect($payment_url);
    }

    public function orderConfirm(Request $request){
    	// var_dump(session('cart_id'));die();
    	$order_id = $request->id;
    	$order = Order::find($order_id);
    	if($order->type != 'pickup'){
    		$order = Order::join('areas', 'areas.id', '=', 'orders.billing_area')->where('orders.id', $order_id)->select('orders.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->first();
    	}
    	if($order->pay_type != 'cod'){
    		$payment_id = $request->payment_id; //100423410000019747
    		$result = $request->result; //NOT%20CAPTURED
    		$tran_id = $request->tran_id; //423410001505523
    		$ref = $request->ref; //423410001511
    		$track_id = $request->track_id; //019175898c3594fe2b3df2c7c9f75f1b
    		$order_id = $request->order_id; //019175898c7a29646b8dbdae85f9a8c4v2
    		$invoice_id = $request->invoice_id; //5985516
    		$receipt_id = $request->receipt_id; //019175898c7a29646b8dbdae85f9a8c4v2
    		
    		$order->payment_id = $payment_id;
    		$order->pay_status = $result;
    		$order->tran_id = $tran_id;
    		$order->ref_id = $ref;
    		$order->track_id = $track_id;
    		$order->order_id = $order_id;
    		$order->invoice_id = $invoice_id;
    		$order->receipt_id = $receipt_id;
    		$order->save();
    	}

    	$address = [];
    	if($order->address_id )
    		$address = AddressBook::join('areas', 'areas.id', '=', 'address_books.area')->where('address_books.id',$order->address_id)->select('address_books.*', 'areas.name_en as area_en', 'areas.name_ar as area_ar')->first();
    	
    	if($order->pay_type=='cod' || strtolower($order->pay_status)=='captured'){

	    	$update = Cart::find(session('cart_id'));
	    	// var_dump(session('cart_id'));
	    	// var_dump($update);die();
	    	$update->order_id=$order->id;
	    	$update->save();

	    	// var_dump(session()->all());die();
	    	$carts = Cart::where('order_id', $order->id)->first();
	    	$cartItems = CartItem::where('cart_id',$carts->id)->get();
	    	if(session('cart-data')){
		    	foreach($cartItems as $cart){
		    		$quantity = $cart->quantity;
		    		$weight = $cart->weight;
		    		$product = Product::find($cart->product_id);
		    		$sizes = json_decode($product->quantity, true);
		    		$sizes[$weight] = $sizes[$weight]-$quantity;
		    		$product->quantity = json_encode($sizes);
		    		$product->save();
		    	}
		    	session()->forget('cart-data');
	    		session()->forget('cart-address');
	    	}
	    	$ncart = [];
			$total = $addonTotal = [];
			foreach($cartItems as $key=>$row){
				$nadd = [];
				if($row->addon){
					$addons = json_decode($row->addon, true);
					foreach($addons as $akey=>$addon){
						$qty = $addon['qty'];
						$price = $addon['price'];
						$avalue = AddonValue::find($akey);
						$operand = $avalue->operand;
						$price_type = $avalue->price_type;
						$addonTotal[] = $addon['price']*$addon['qty'];
						$nadd[] = array(
							'addon' => $avalue,
							'qty' => $qty,
							'price' => $price,
							'operand' => $operand,
							'price_type' => $price_type,
						);
					}
				}

				$total[] = $row->quantity*$row->price;
				$ncart[$key] = $row;
				$ncart[$key]['cart'] = $carts;
				$ncart[$key]['product'] = Product::find($row->product_id);
				$ncart[$key]['slot'] = Timeslot::find($row->slot);
				$ncart[$key]['area'] = Area::find($row->area_id);
				$ncart[$key]['addons'] = $nadd;

			}
    	}

		$branch = [];
		if($order->type =='pickup'){
			$branch = Branch::find($order->branch_id);
		}

		if(strtolower($order->pay_status) == 'not captured')
			return view('frontend.ordercancel', ['branch'=>$branch, 'order'=>$order]);

    	return view('frontend.confirm', ['branch'=>$branch, 'order'=>$order, 'cart'=>$ncart, 'total'=>$total, 'address'=>$address,'addons'=>$nadd,'addontotal'=> $addonTotal]);
    }    

    public function checkCoupon($code){
    	$coupon = Coupon::where('code',$code)->first();
    	if(!$coupon){
    		return response()->json(['msg' => 'Invalid Coupon Code','result' => 'error']);
    	} else {
    		// var_dump($coupon->created_at);die();
    		$start_dt = explode('/', $coupon->start_dt);
    		$start_dt = strtotime($start_dt[2].'-'.$start_dt[1].'-'.$start_dt[0]);
    		$end_dt = explode('/', $coupon->end_at);
    		$end_dt = strtotime($end_dt[2].'-'.$end_dt[1].'-'.$end_dt[0]);
    		$today = strtotime('today');    		

    		if($today < $start_dt || $today > $end_dt){
    			if($today<$start_dt)
    				return response()->json(['msg' => 'Code is valid after'.$coupon->start_dt,'result' => 'error']);
    			if($today>$coupon->end_dt)
    				return response()->json(['msg' => 'Coupon is expired!!','result' => 'error']);
    		} else {
    			$type = $coupon->type;
    			$discount = $coupon->amount;    			

    			if(auth()->check())
    				$cart = Cart::where('user_id',session('id'))->where('order_id',0)->first();
    			else
    				$cart = Cart::where('ip',$this->get_client_ip())->where('order_id',0)->first();

    			$subtotal = $cart->subtotal;
    			if(strtolower($type) == 'percentage'){
    				$discount = ($discount/100) * $subtotal;
    			}
    			$cart->coupon = $code;
    			$cart->discount = $discount;
    			$cart->save();

    			return response()->json(['data'=>$cart, 'msg' => 'Coupon Applied!!','result' => 'success']);
    		}
    	}
    }

    public static function getCart(){

    	$ip = static::get_client_ip();

    	$cart_id = session('cart_id');
    	$cart = CartItem::query()
    		->join('carts', 'carts.id', '=', 'cart_items.cart_id')
    		->where('cart_id', $cart_id)
    		->where('order_id',0)
    		->get(['cart_items.*','carts.coupon','carts.subtotal','carts.discount','carts.delivery']);
	
		$ncart = [];
		$total = $addonTotal = [];

		foreach($cart as $key=>$row){
			$nadd = [];
			if($row->addon){
				$addons = json_decode($row->addon, true);					
				foreach($addons as $akey=>$addon){
					$qty = $addon['qty'];
					$price = $addon['price'];
					$avalue = AddonValue::find($akey);
					$operand = $avalue->operand;
					$price_type = $avalue->price_type;
					$addonTotal[] = $addon['price']*$addon['qty'];
					$nadd[] = array(
						'addon' => $avalue,
						'qty' => $qty,
						'price' => $price,
						'operand' => $operand,
						'price_type' => $price_type,
					);
				}
			}
			$total[] = ($row->quantity*$row->price);
			$ncart[$key] = $row;
			$ncart[$key]['product'] = Product::find($row->product_id);
			$ncart[$key]['slot'] = Timeslot::find($row->slot);
			$ncart[$key]['area'] = Area::find($row->area_id);
			$ncart[$key]['branch'] = Branch::find($row->branch_id);
			$ncart[$key]['addons'] = $nadd;
		}
		return json_encode(['cart'=>$ncart,'total'=>$total,'addontotal'=> $addonTotal]);
    }

    public static function get_client_ip() {
	    $ipaddress = '';
	    if (isset($_SERVER['HTTP_CLIENT_IP']))
	        $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
	    else if(isset($_SERVER['HTTP_X_FORWARDED_FOR']))
	        $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
	    else if(isset($_SERVER['HTTP_X_FORWARDED']))
	        $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
	    else if(isset($_SERVER['HTTP_FORWARDED_FOR']))
	        $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
	    else if(isset($_SERVER['HTTP_FORWARDED']))
	        $ipaddress = $_SERVER['HTTP_FORWARDED'];
	    else if(isset($_SERVER['REMOTE_ADDR']))
	        $ipaddress = $_SERVER['REMOTE_ADDR'];
	    else
	        $ipaddress = 'UNKNOWN';
	    return $ipaddress;
	}

	function updateAmount($cartid){
		$cartItems = CartItem::where('cart_id',$cartid)->get();
		$amount = $addTotal = [];
		foreach($cartItems as $item){
			$amount[] = $item->quantity*$item->price;
			$addons = json_decode($item->addon, true);
			if($addons){
				foreach($addons as $k=>$addon){
				// 	var_dump($addon);
					$addTotal[] = $addon['qty']*$addon['price'];
				}
			}
		}
		$subtotal = array_sum($amount) + array_sum($addTotal);
		$cart = Cart::find($cartid);
		if($cart->coupon){
			$coupon = Coupon::where('code',$cart->coupon)->first();
			$type = $coupon->type;
			$discount = $coupon->amount;
			if(strtolower($type) == 'percentage'){
				$discount = ($discount/100) * $subtotal;
			}	    			
			$cart->discount = $discount;
		}
		$cart->subtotal = $subtotal;
		$cart->save();
	}

	public function payment_link($order_id, $pay_type){
		if($pay_type!='knet'){
			$pay_type = 'cc';
		}
		$order = Order::find($order_id);
		$cart = Cart::find(session('cart_id'));
		$user_id = ($order->user_id)?$order->user_id:0;

		$postdata = json_encode([
			'order' => [
			    'id' => (string)$order_id,
			    'reference' => (string)$cart->id,
			    'description' => 'Test product',
			    'currency' => 'KWD',
			    'amount' => (float)$cart->subtotal - (float)$cart->discount
			],
			'language' => (session('locale'))?session('locale'):'en',
			'paymentGateway' => [
			    'src' => $pay_type
			],
			'reference' => [
			    'id' => (string)$cart->id
			],
			'customer' => [
			    'uniqueId' => (string)$user_id,
			    'name' => $order->billing_name,
			    'email' => $order->billing_email,
			    'mobile' => '+965'.$order->billing_phone
			],
			'returnUrl' => route('order.confirm', ['id'=> $order->id]),
			'cancelUrl' => route('order.confirm', ['id'=> $order->id]),
			'notificationUrl' => route('order.notify', ['id'=> $order->id]),
		]);
		// var_dump($postdata);die();

		$curl = curl_init();

		curl_setopt_array($curl, [
			CURLOPT_URL => "https://sandboxapi.upayments.com/api/v1/charge",
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 30,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "POST",
			CURLOPT_POSTFIELDS => $postdata,
			CURLOPT_HTTPHEADER => [
				"Authorization: Bearer jtest123",//9sHYMj3umH7KFfplbJBvH1PoH7SeClKY1Gb9GYag
				"accept: application/json",
				"content-type: application/json"
			],
		]);

		$response = curl_exec($curl);
		$err = curl_error($curl);

		curl_close($curl);

		if ($err) {
			var_dump($err);die();
		  	return "cURL Error #:" . $err;
		} else {
			$result = json_decode($response, true);
			$link = $result['data']['link'];
		  	return $link;
		}
	}

	public function orderCancel(Request $request){
	}

	public function orderNotify(Request $request){
		
	}
}