<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Branch;
use App\Models\Area;
use App\Models\Timeslot;
use App\Models\Product;
use App\Models\Category;
use App\Models\Addon;
use App\Models\Occasion;
use App\Models\Cart;
use App\Models\CartItem;
use App\Models\Order;
use App\Models\AddonValue;
use App\Models\Contact;
use App\Models\GuestUser;
use App\Mail\AbondMail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Builder;

class FrontendController extends Controller
{
    public function index() {
        $categories = Category::where('active',1)->get();
        $occasions = Occasion::where('active',1)->get();
        $products = Product::where('visible',1)->inRandomOrder()->limit(5)->get();
        return view('frontend.home',['occasions'=>$occasions,'categories'=>$categories, 'products'=>$products]);
    }

    public function getSlots(Request $request){
        $date = $request->del_dt;
        $branch = $request->branch;
        $day = date('l', strtotime($date));
        $slots = Timeslot::where('branch_id', $branch)->where('day','like', $day)->where('show',1)->get();
        $html = '';
        if(count($slots)){
            foreach($slots as $key=>$slot){
                $html .= '<li>
                    <div class="radio time">
                        <input id="time-'.$key.'" name="slot" type="radio" '.(($key==0)?'checked':'').' data-name="Between '.date('h:i A', strtotime($slot->start)).' To '.date('h:i A', strtotime($slot->end)).'" value="'.$slot->id.'">
                        <label for="time-'.$key.'" class="radio-label">Between '.date('h:i A', strtotime($slot->start)).' To '.date('h:i A', strtotime($slot->end)).'</label>
                    </div>
                </li>';
            }            
        } else {
            $html = '<li>No Slots available</li>';
        }
        
        return response()->json(['html' => $html,'result' => 'success']);
    }
    
    public function addAddress(){
        return view('frontend.add-address');
    }

    public function contact(Request $request){
        $contact = new Contact;

        $contact->name = $request->name;
        $contact->email = $request->email;
        $contact->phone = $request->phone;
        $contact->subject = $request->subject;
        $contact->message = $request->message;
        $contact->save();

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Submitted successfully!');
        return redirect()->back();
    }

    public function search(Request $request){
        $keyword = $request->keyword;

        $products = Product::where('name_en','LIKE', '%'.$keyword.'%')->get();
        $html = '';
        foreach($products as $product){
            $html .='
            <li class="p-2">
                <a href="'.route('single.product', ['slug'=>$product->slug]).'">
                    <img src="/gallery/products/images/'.$product->thumbnail.'" style="width: 15%;margin-right: 10px;">
                    <span>'.(app()->getLocale()=='en'?$product->name_en:$product->name_ar).'</span>
                </a>
            </li>';
        }

        return response()->json(['html'=>$html]);
    }

    public function abondonedmail(){
        $updated = date('Y-m-d h:i:s', strtotime('-1 hour'));
        // $order = Order::where('pay_status', 'NOT CAPTURED')->where('')->get();
        $carts = Cart::where('order_id',0)->where('updated_at','<=',$updated)->where('mail',0)->get();

        foreach($carts as $cart){
            $uemail = $uname = '';
            $cartItems = CartItem::where('cart_id', $cart->id)->get();
            if($cart->user_id){
                $user = User::find($cart->user_id);
                $uemail = $user->email;
                $uname = $user->name;
            } else {
                $guest = GuestUser::where('cart_id', $cart->id)->first();
                if($guest){
                    $uemail = $guest->email;
                    $uname = $guest->name;
                }
            }
            // var_dump($uemail);
            
            if($uemail){
                $citem = [];
                foreach($cartItems as $key=>$item){
                    // $citem[$key] = $item;
                    $citem[$key]['product'] = Product::find($item->product_id);
                    $citem[$key]['weight'] = $item->weight;
                    $citem[$key]['price'] = $item->price;
                    $citem[$key]['quantity'] = $item->quantity;
                    $citem[$key]['addons'] = [];
                    $addons = [];
                    if($item->addon){
                        $addonList = json_decode($item->addon, true);
                        foreach($addonList as $akey=>$addon){
                            $qty = $addon['qty'];
                            $price = $addon['price'];
                            $avalue = AddonValue::find($akey);
                            $operand = $avalue->operand;
                            $price_type = $avalue->price_type;
                            $addonTotal[] = $addon['price']*$addon['qty'];
                            $citem[$key]['addons'][] = array(
                                'addon' => $avalue,
                                'qty' => $qty,
                                'price' => $price,
                            );
                        }
                    }
                }
                
                if(Mail::to($uemail)->send(new AbondMail($citem, $uname))){
                    echo 'sent';
                } else {
                    echo 'not sent';
                }
                $data = Cart::find($cart->id);
                // $data->mail = 1;
                // $data->save();
            }
        }
    }
}
