<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Product;
use App\Models\Branch;
use App\Models\BranchExclude;
use App\Models\BranchPickup;
use App\Models\BranchArea;
use App\Models\Area;
use App\Models\Timeslot;
use App\Models\Category;
use App\Models\Occasion;
use App\Models\Addon;
use App\Models\AddonValue;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Database\Eloquent\Builder;

class ProductController extends Controller
{

    public function index(Request $request)
    {
        \DB::enableQueryLog();
        if($request->sort_by){
            $sort_by = $request->sort_by;
            if($sort_by == 'new' || $sort_by == 'default'){
                $sort['order'] = 'desc';
                $sort['column'] = 'updated_at';
            }elseif($sort_by == 'price_low'){
                $sort['order'] = 'asc';
                $sort['column'] = 'dsale_price';
            }elseif($sort_by == 'price_high'){
                $sort['order'] = 'desc';
                $sort['column'] = 'dsale_price';
            }
        } else {
            $sort['order'] = 'desc';
            $sort['column'] = 'updated_at';
        }
        $excludeIds = [];
        if(session('deliveryType')=='Pickup'){
            $branch_id = session('sel-branch');
            $pickups = BranchPickup::where('branch_id', $branch_id)->first();
            if($pickups)
                $excludeIds = json_decode($pickups->pid, true);
        }

        // $sort = json_decode($request->get('sort_by', json_encode(['order' => 'desc', 'column' => 'updated_at'], JSON_THROW_ON_ERROR)), true, 512, JSON_THROW_ON_ERROR);
        $products = Product::join('categories', 'categories.id', '=', 'products.category_id')
            ->join('occasions', 'occasions.id', '=', 'products.occasion_id')
            ->where('visible', 1)
            ->whereNotIn('products.id', $excludeIds)
            ->where(function (Builder $query) use ($request) {
                if($request->category){
                    $category = $request->category;
                    $query->whereIn('categories.slug', $category);
                }
                if($request->size){
                    $sizes = $request->size;
                    foreach($sizes as $size){
                        $query->orWhere('measurements','like', '%'.$size.'%');
                    }
                }
                if($request->occasion){
                    $occasion = $request->occasion;
                    $query->whereIn('occasions.slug', $occasion);
                }
                
            })
            ->select('products.*', 'categories.name_en as cat_name_en', 'categories.name_ar as cat_name_ar', 'occasions.name_en as occ_name_en', 'occasions.name_ar as occ_name_ar')
            ->orderBy($sort['column'], $sort['order'])
            ->paginate(10);
        
        // dump(\DB::getQueryLog());
        // var_dump(count($query));die();

        $categories = Category::where('active',1)->get();
        $occasions = Occasion::where('active',1)->get();
        return view('frontend.product-listing', ['products' => $products, 'occasions'=>$occasions, 'categories'=>$categories, 'request'=>$request->all()]);
    }

    public function categoryPage(Request $request){
        if($request->sort_by){
            $sort_by = $request->sort_by;
            if($sort_by == 'new' || $sort_by == 'default'){
                $sort['order'] = 'desc';
                $sort['column'] = 'products.updated_at';
            }elseif($sort_by == 'price_low'){
                $sort['order'] = 'asc';
                $sort['column'] = 'dsale_price';
            }elseif($sort_by == 'price_high'){
                $sort['order'] = 'desc';
                $sort['column'] = 'dsale_price';
            }
        } else {
            $sort['order'] = 'desc';
            $sort['column'] = 'products.updated_at';
        }
        $excludeIds = [];
        if(session('deliveryType')=='Pickup'){
            $branch_id = session('sel-branch');
            $pickups = BranchPickup::where('branch_id', $branch_id)->first();
            if($pickups)
                $excludeIds = json_decode($pickups->pid, true);
        }
        $category = Category::where('slug', $request->slug)->first();
        $products = Product::query()
            ->join('occasions', 'occasions.id', '=', 'products.occasion_id')
            ->join('categories', 'categories.id', '=', 'products.category_id')
            ->where('visible',1)
            ->whereNotIn('products.id', $excludeIds)
            ->where(function (Builder $query) use ($request) {
                if($request->size){
                    $sizes = $request->size;
                    foreach($sizes as $size){
                        $query->orWhere('measurements','like', '%'.$size.'%');
                    }
                }
                if($request->occasion){
                    $occasion = $request->occasion;
                    $query->whereIn('occasions.slug', $occasion);
                }                
            })
            ->where('category_id',$category->id)
            ->select('products.*', 'categories.name_en as cat_name_en', 'categories.name_ar as cat_name_ar', 'occasions.name_en as occ_name_en', 'occasions.name_ar as occ_name_ar')
            ->orderBy($sort['column'], $sort['order'])
            ->paginate(10);
        
        $occasions = Occasion::where('active',1)->get();
        $otherCat = Category::whereNot('id',$category->id)->where('active',1)->get();
        return view('frontend.category', ['occasions'=>$occasions,'category'=>$category, 'products'=>$products, 'other_categories'=>$otherCat, 'request'=>$request->all()]);
    }

    public function occasionPage(Request $request){
        if($request->sort_by){
            $sort_by = $request->sort_by;
            if($sort_by == 'new' || $sort_by == 'default'){
                $sort['order'] = 'desc';
                $sort['column'] = 'products.updated_at';
            }elseif($sort_by == 'price_low'){
                $sort['order'] = 'asc';
                $sort['column'] = 'dsale_price';
            }elseif($sort_by == 'price_high'){
                $sort['order'] = 'desc';
                $sort['column'] = 'dsale_price';
            }
        } else {
            $sort['order'] = 'desc';
            $sort['column'] = 'products.updated_at';
        }
        $excludeIds = [];
        if(session('deliveryType')=='Pickup'){
            $branch_id = session('sel-branch');
            $pickups = BranchPickup::where('branch_id', $branch_id)->first();
            if($pickups)
                $excludeIds = json_decode($pickups->pid, true);
        }
        $occasion = Occasion::where('slug', $request->slug)->first();
        $products = Product::query()
            ->join('categories', 'categories.id', '=', 'products.category_id')
            ->join('occasions', 'occasions.id', '=', 'products.occasion_id')
            ->where('visible',1)
            ->whereNotIn('products.id', $excludeIds)
            ->where(function (Builder $query) use ($request) {
                if($request->size){
                    $sizes = $request->size;
                    foreach($sizes as $size){
                        $query->orWhere('measurements','like', '%'.$size.'%');
                    }
                }
                if($request->category){
                    $category = $request->category;
                    $query->whereIn('categories.slug', $category);
                }                
            })
            ->where('occasion_id',$occasion->id)
            ->select('products.*', 'categories.name_en as cat_name_en', 'categories.name_ar as cat_name_ar', 'occasions.name_en as occ_name_en', 'occasions.name_ar as occ_name_ar')
            ->orderBy($sort['column'], $sort['order'])
            ->paginate(10);
        
        $categories = Category::where('active',1)->get();
        $otherCat = Category::where('active',1)->get();
        return view('frontend.occasion', ['occasion'=>$occasion, 'categories'=>$categories, 'products'=>$products, 'other_categories'=>$otherCat, 'request'=>$request->all()]);
    }

    public function singleProduct($slug){
        $product = Product::join('categories', 'categories.id', '=', 'products.category_id')->where('products.slug', $slug)->select('products.*','categories.name_en as cat_name_en','categories.name_ar as cat_name_ar')->first();
        
        /* Branch Areas Start */
        $newB = [];
        $newArea = [];$a = [];
        $branches = Branch::all();        
        foreach($branches as $branch){
            $excludes = BranchExclude::where('branch_id', $branch->id)->first();
            $pids = [];
            if($excludes)
                $pids = json_decode($excludes->pid, true);

            if(!in_array($product->id, $pids)){
                $newB[] = $branch;
                $areas = BranchArea::where('branch_id',$branch->id)->first();
                if($areas){
                    $aids = json_decode($areas->area_id, true);
                    
                    foreach($aids as $aid){
                        foreach($aid as $area){
                            if(!in_array($area, $a)){
                                $a[] = $area;
                                $newArea[$branch->id][$area] = Area::find($area);
                            }
                        }
                    }                                       
                }
            }
        }
        $branches = $newB;
        /* Branch Areas End */

        /* Delivery Time Start */
        $slots = [];
        $day = date('l', strtotime('+1 day'));
        if(count($branches))
            $slots = Timeslot::where('branch_id', $newB[0]->id)->where('day',$day)->where('show',1)->get();
        /* Delivery Time End */

        /* Pickup Start */
        $pickupIds = [];
        $newpick = $newP = [];
        $pbranches = Branch::where('pickup',1)->get();
        foreach($pbranches as $branch){
            $pickups = BranchPickup::where('branch_id', $branch->id)->first();
            if($pickups){
                $pickupId = json_decode($pickups->pid, true);
                foreach($pickupId as $id){
                    $pickupIds[] = $id;
                }
                if(!in_array($product->id, $pickupId)){
                    $newP[] = $branch;
                }
            } else {
                $newP[] = $branch;
            }
        }
        $ids = array_count_values($pickupIds);        
        $pickupData = $newP;
        /* Pickup End */

        /*Addon Start*/
        $addons = Addon::all();
        $naddons = [];
        foreach($addons as $key=>$addon){
            $naddons[$key]['main'] = $addon;
            $naddons[$key]['value'] = AddonValue::where('visible',1)->where('addon_id',$addon->id)->get();
        }
        /*Addon End*/

        $categories = Category::where('active',1)->get();
        $recommended = Product::where('category_id', $product->category_id)->where('visible',1)->whereNot('id', $product->id)->get();
        
        return view('frontend.product-details', [
            'product'=>$product, 
            'addons'=>$addons, 
            'branches'=>$branches, 
            'addons'=>$naddons,
            'categories' => $categories,
            'slots' =>$slots,
            'areas' => $newArea,
            'recommended' => $recommended,
            'pickups' => $pickupData
        ]);
    }

    public function create()
    {
        if (session('role') == 'admin') {
            return view('admin.addon.create');
        }
        return redirect()->back();
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_en' => 'required',
            'name_ar' => 'required',
            'input_type' => 'required',
         ]);

        $addon = new Addon;

        $addon->name_en = $request->name_en;
        $addon->name_ar = $request->name_ar;
        $addon->input_type = $request->input_type;
        $addon->minimum = ($request->minimum)?$request->minimum:0;
        $addon->maximum = ($request->maximum)?$request->maximum:0;
        $addon->save();

        foreach($request->value_en as $key=>$enval){
            $addonValue = new AddonValue;
            $addonValue->addon_id = $addon->id;
            $addonValue->name_en = $enval;
            $addonValue->name_ar = $request->value_ar[$key];
            $addonValue->price = $request->price[$key];
            $addonValue->price_type = $request->price_type[$key];
            $addonValue->operand = $request->operand[$key];
            $addonValue->visible = $request->show[$key];
            $addonValue->save();
        }

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Addon added successfully!');
        return redirect()->route('addon.list');
    }

    public function edit($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $addon = Addon::find($id);
        $values = AddonValue::where('addon_id', $id)->get();
        return view('admin.addon.update', ['addon' => $addon, 'values'=>$values]);
    }

    public function update(Request $request)
    {
        $id = (session('role') == 'admin') ? $request->id : session('id');

        $validation = [
            'name_en' => 'required',
            'name_ar' => 'required',
            'input_type' => 'required',
        ];

        $request->validate($validation);

        $addon = Addon::find($id);

        $addon->name_en = $request->name_en;
        $addon->name_ar = $request->name_ar;
        $addon->input_type = $request->input_type;
        $addon->minimum = ($request->minimum)?$request->minimum:0;
        $addon->maximum = ($request->maximum)?$request->maximum:0;
        $addon->save();

        $requestIds = $request->ids;
        $ids = AddonValue::where('addon_id',$id)->get();
        foreach($ids as $id){
            if(!in_array($id->id, $requestIds)){
                AddonValue::find($id->id)->delete();
            }
        }
        foreach($request->value_en as $key=>$enval){
            if($request->ids[$key]!=NULL)
                $addonValue = AddonValue::find($request->ids[$key]);
            else
                $addonValue = new AddonValue;

            $addonValue->addon_id = $addon->id;
            $addonValue->name_en = $enval;
            $addonValue->name_ar = $request->value_ar[$key];
            $addonValue->price = $request->price[$key];
            $addonValue->price_type = $request->price_type[$key];
            $addonValue->operand = $request->operand[$key];
            $addonValue->visible = isset($request->show[$key])?$request->show[$key]:0;
            $addonValue->save();
        }

        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Info updated successfully!');
        return redirect()->route('addon.list');
    }

    public function delete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $addon = Addon::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Addon deleted successfully!');
        return redirect()->back();
    }
    public function addVDelete($id)
    {
        $id = (session('role') == 'admin') ? $id : session('id');
        $value = AddonValue::find($id)->delete();
        session()->flash('alert-class', 'alert-success');
        session()->flash('alert-msg', 'Value deleted successfully!');
        return redirect()->back();
    }

}
