<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\AddonController;
use App\Http\Controllers\Admin\ReportController;
use App\Http\Controllers\Admin\AnnouncementController;
use App\Http\Controllers\Admin\BranchController;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\OccasionController;
use App\Http\Controllers\Admin\CouponController;
use App\Http\Controllers\Admin\DashboardController;
use App\Http\Controllers\Admin\OrderController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\ReviewController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\SettingController;
use App\Http\Controllers\AuthenticationController;

use App\Http\Controllers\FrontendController;
use App\Http\Controllers\AccountController;
use App\Http\Controllers\ProductController as FProductController;
use App\Http\Controllers\CartController;

// Route::get('/', function () {
//     return view('welcome');
// });

Route::get('/', [FrontendController::class, 'index'])->name('home');

Route::get('login', [AuthenticationController::class, 'login'])->name('login');
Route::post('login', [AuthenticationController::class, 'loginSubmit'])->name('auth');
Route::get('logout', [AuthenticationController::class, 'logout'])->name('logout');

Route::post('register', [AuthenticationController::class, 'register'])->name('register');

Route::middleware('auth')->group(function () {
    Route::prefix('admin')->name('admin.')->group(function () { //
        Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');

        // AddonController
        Route::get('addon', [AddonController::class, 'index'])->name('addon.list');
        Route::get('addon/create', [AddonController::class, 'create'])->name('addon.create');
        Route::post('addon/create', [AddonController::class, 'store'])->name('addon.store');
        Route::get('addon/update/{id}', [AddonController::class, 'edit'])->name('addon.edit');
        Route::post('addon/update/{id}', [AddonController::class, 'update'])->name('addon.update');
        Route::get('addon/delete/{id}', [AddonController::class, 'delete'])->name('addon.delete');
        Route::get('addon-value/delete/{id}', [AddonController::class, 'addVDelete'])->name('addonv.delete');
        
        // AnnouncementController
        Route::get('announcement', [AnnouncementController::class, 'index'])->name('announcement.list');
        Route::get('announcement/create', [AnnouncementController::class, 'create'])->name('announcement.create');
        Route::post('announcement/create', [AnnouncementController::class, 'store'])->name('announcement.store');
        Route::get('announcement/update/{id}', [AnnouncementController::class, 'edit'])->name('announcement.edit');
        Route::post('announcement/update/{id}', [AnnouncementController::class, 'update'])->name('announcement.update');
        Route::get('announcement/delete/{id}', [AnnouncementController::class, 'delete'])->name('announcement.delete');

        // BranchController
        Route::get('branch', [BranchController::class, 'index'])->name('branch.list');
        Route::get('branch/create', [BranchController::class, 'create'])->name('branch.create');
        Route::post('branch/create', [BranchController::class, 'store'])->name('branch.store');
        Route::get('branch/update/{slug}', [BranchController::class, 'edit'])->name('branch.edit');
        Route::post('branch/update/{slug}', [BranchController::class, 'update'])->name('branch.update');
        Route::get('branch/delete/{slug}', [BranchController::class, 'delete'])->name('branch.delete');

        Route::get('branch/{slug}/area', [BranchController::class, 'addArea'])->name('branch.area');
        Route::post('branch/{slug}/area', [BranchController::class, 'storeArea'])->name('branch.area.store');

        Route::get('branch/{slug}/exclude', [BranchController::class, 'exclude'])->name('branch.exclude');
        Route::post('branch/{slug}/exclude', [BranchController::class, 'excludeProducts'])->name('branch.exclude.store');

        Route::get('branch/{slug}/pickup', [BranchController::class, 'excludePickup'])->name('branch.pickup');
        Route::post('branch/{slug}/pickup', [BranchController::class, 'excludePickupProducts'])->name('branch.pickup.store');

        Route::get('branch/{slug}/time-slot', [SettingController::class, 'timeSlot'])->name('setting.timeslot');
        Route::post('branch/{slug}/time-slot', [SettingController::class, 'timeSlotStore'])->name('setting.timeslot.store');

        // Setting Controller
        // Setting state
        Route::get('setting/state', [SettingController::class, 'indexState'])->name('setting.state.list');
        Route::get('setting/state/create', [SettingController::class, 'createState'])->name('setting.state.create');
        Route::post('setting/state/create', [SettingController::class, 'storeState'])->name('setting.state.store');
        Route::get('setting/state/update/{id}', [SettingController::class, 'editState'])->name('setting.state.edit');
        Route::post('setting/state/update/{id}', [SettingController::class, 'updateState'])->name('setting.state.update');
        Route::get('setting/state/delete/{id}', [SettingController::class, 'deleteState'])->name('setting.state.delete');

        // Setting area
        Route::get('setting/area', [SettingController::class, 'indexArea'])->name('setting.area.list');
        Route::get('setting/area/create', [SettingController::class, 'createArea'])->name('setting.area.create');
        Route::post('setting/area/create', [SettingController::class, 'storeArea'])->name('setting.area.store');
        Route::get('setting/area/update/{id}', [SettingController::class, 'editArea'])->name('setting.area.edit');
        Route::post('setting/area/update/{id}', [SettingController::class, 'updateArea'])->name('setting.area.update');
        Route::get('setting/area/delete/{id}', [SettingController::class, 'deleteArea'])->name('setting.area.delete');

        // CategoryController
        Route::get('category', [CategoryController::class, 'index'])->name('category.list');
        Route::get('category/create', [CategoryController::class, 'create'])->name('category.create');
        Route::post('category/create', [CategoryController::class, 'store'])->name('category.store');
        Route::get('category/update/{slug}', [CategoryController::class, 'edit'])->name('category.edit');
        Route::post('category/update/{slug}', [CategoryController::class, 'update'])->name('category.update');
        Route::get('category/delete/{slug}', [CategoryController::class, 'delete'])->name('category.delete');

        // OccasionController
        Route::get('occasion', [OccasionController::class, 'index'])->name('occasion.list');
        Route::get('occasion/create', [OccasionController::class, 'create'])->name('occasion.create');
        Route::post('occasion/create', [OccasionController::class, 'store'])->name('occasion.store');
        Route::get('occasion/update/{slug}', [OccasionController::class, 'edit'])->name('occasion.edit');
        Route::post('occasion/update/{slug}', [OccasionController::class, 'update'])->name('occasion.update');
        Route::get('occasion/delete/{slug}', [OccasionController::class, 'delete'])->name('occasion.delete');

        // CouponController
        Route::get('coupon', [CouponController::class, 'index'])->name('coupon.list');
        Route::get('coupon/create', [CouponController::class, 'create'])->name('coupon.create');
        Route::post('coupon/create', [CouponController::class, 'store'])->name('coupon.store');
        Route::get('coupon/update/{id}', [CouponController::class, 'edit'])->name('coupon.edit');
        Route::post('coupon/update/{id}', [CouponController::class, 'update'])->name('coupon.update');
        Route::get('coupon/delete/{id}', [CouponController::class, 'delete'])->name('coupon.delete');

        // OrderController
        Route::get('order', [OrderController::class, 'index'])->name('order.list');
        Route::get('order/deleted', [OrderController::class, 'showDeleted'])->name('order.deleted');
        Route::get('order/view/{id}', [OrderController::class, 'view'])->name('order.view');
        // Route::post('order/create', [OrderController::class, 'store'])->name('order.store');
        // Route::get('order/update/{slug}', [OrderController::class, 'edit'])->name('order.edit');
        Route::post('order/update/{id}', [OrderController::class, 'update'])->name('order.update');
        Route::get('order/delete/{id}', [OrderController::class, 'delete'])->name('order.delete');

        // ProductController
        Route::get('product', [ProductController::class, 'index'])->name('product.list');
        Route::get('product/create', [ProductController::class, 'create'])->name('product.create');
        Route::post('product/create', [ProductController::class, 'store'])->name('product.store');
        Route::get('product/update/{slug}', [ProductController::class, 'edit'])->name('product.edit');
        Route::post('product/update/{slug}', [ProductController::class, 'update'])->name('product.update');
        Route::get('product/delete/{slug}', [ProductController::class, 'delete'])->name('product.delete');
        
        // ReviewController
        Route::get('review', [ReviewController::class, 'index'])->name('review.list');
        Route::get('review/create', [ReviewController::class, 'create'])->name('review.create');
                
        // UserController
        Route::get('user', [UserController::class, 'index'])->name('user.list');
        Route::get('user/create', [UserController::class, 'create'])->name('user.create');
        Route::post('user/create', [UserController::class, 'store'])->name('user.store');
        Route::get('user/update/{id}', [UserController::class, 'edit'])->name('user.edit');
        Route::post('user/update/{id}', [UserController::class, 'update'])->name('user.update');
        Route::get('user/delete/{id}', [UserController::class, 'delete'])->name('user.delete');

        // Route::get('time-slot', [SettingController::class, 'timeSlot'])->name('setting.timeslot');
        // Route::post('time-slot', [SettingController::class, 'timeSlotStore'])->name('setting.timeslot.store');
    });
    Route::prefix('branch')->name('branch.')->group(function () { //
        Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');

        // BranchController
        Route::get('branch', [BranchController::class, 'index'])->name('branch.list');
        Route::get('branch/create', [BranchController::class, 'create'])->name('branch.create');
        Route::post('branch/create', [BranchController::class, 'store'])->name('branch.store');
        Route::get('branch/update/{slug}', [BranchController::class, 'edit'])->name('branch.edit');
        Route::post('branch/update/{slug}', [BranchController::class, 'update'])->name('branch.update');
        Route::get('branch/delete/{slug}', [BranchController::class, 'delete'])->name('branch.delete');

        Route::get('branch/{slug}/area', [BranchController::class, 'addArea'])->name('branch.area');
        Route::post('branch/{slug}/area', [BranchController::class, 'storeArea'])->name('branch.area.store');

        Route::get('branch/{slug}/exclude', [BranchController::class, 'exclude'])->name('branch.exclude');
        Route::post('branch/{slug}/exclude', [BranchController::class, 'excludeProducts'])->name('branch.exclude.store');

        Route::get('branch/{slug}/pickup', [BranchController::class, 'excludePickup'])->name('branch.pickup');
        Route::post('branch/{slug}/pickup', [BranchController::class, 'excludePickupProducts'])->name('branch.pickup.store');

        Route::get('branch/{slug}/time-slot', [SettingController::class, 'timeSlot'])->name('setting.timeslot');
        Route::post('branch/{slug}/time-slot', [SettingController::class, 'timeSlotStore'])->name('setting.timeslot.store');

        
        // OrderController
        Route::get('order', [OrderController::class, 'index'])->name('order.list');
        Route::get('order/deleted', [OrderController::class, 'showDeleted'])->name('order.deleted');
        Route::get('order/view/{id}', [OrderController::class, 'view'])->name('order.view');
        // Route::post('order/create', [OrderController::class, 'store'])->name('order.store');
        // Route::get('order/update/{slug}', [OrderController::class, 'edit'])->name('order.edit');
        Route::post('order/update/{id}', [OrderController::class, 'update'])->name('order.update');
        Route::get('order/delete/{id}', [OrderController::class, 'delete'])->name('order.delete');

        
        // ReviewController
        Route::get('review', [ReviewController::class, 'index'])->name('review.list');
        Route::get('review/create', [ReviewController::class, 'create'])->name('review.create');
                
        Route::get('user/update/{id}', [UserController::class, 'edit'])->name('user.edit');
        Route::post('user/update/{id}', [UserController::class, 'update'])->name('user.update');
    });

    Route::post('review/create', [ReviewController::class, 'store'])->name('review.store');
    Route::get('review/view/{id}', [ReviewController::class, 'view'])->name('review.view');
    Route::get('review/update/{id}', [ReviewController::class, 'edit'])->name('review.edit');
    Route::post('review/update/{id}', [ReviewController::class, 'update'])->name('review.update');
    Route::get('review/delete/{id}', [ReviewController::class, 'delete'])->name('review.delete');

    Route::get('abondoned', [ReportController::class, 'abondoned'])->name('abondoned');
    Route::get('sale-by-product', [ReportController::class, 'saleByProduct'])->name('product.sales');
    Route::get('sale-by-branch', [ReportController::class, 'saleByBranch'])->name('branch.sales');
    Route::get('sale-by-area', [ReportController::class, 'saleByArea'])->name('area.sales');
    Route::get('sale-by-customer', [ReportController::class, 'saleByCustomer'])->name('customer.sales');
    Route::get('all-sales', [ReportController::class, 'index'])->name('all.sales');
    Route::get('branch-customers', [ReportController::class, 'customerByBranch'])->name('branch.customer');

    // Account Controller FRONTEND
    Route::get('dashboard', [AccountController::class, 'index'])->name('user.dashboard');
    Route::get('my-account', [AccountController::class, 'myAccount'])->name('my.account');
    Route::post('my-account', [AccountController::class, 'updateProfile'])->name('update.profile');
    Route::get('address-book', [AccountController::class, 'addressBook'])->name('address.book');
    Route::get('add-address', [AccountController::class, 'addAddress'])->name('add-address');
    Route::post('add-address', [AccountController::class, 'addAddressStore'])->name('add.address.store');
    Route::get('update-address/{id}', [AccountController::class, 'updateAddress'])->name('update.address');
    Route::post('update-address/{id}', [AccountController::class, 'updateAddressStore'])->name('update.address.store');
    Route::get('delete-address/{id}', [AccountController::class, 'deleteAddress'])->name('delete.address');
    Route::get('my-orders', [AccountController::class, 'myOrders'])->name('my.orders');
});

Route::get('abondonedmail', [FrontendController::class, 'abondonedmail'])->name('abondonedmail');

Route::get('product/{slug}', [FProductController::class, 'singleProduct'])->name('single.product');
Route::get('products', [FProductController::class, 'index'])->name('products');
Route::get('product-category/{slug}', [FProductController::class, 'categoryPage'])->name('product_cat');
Route::get('occasion/{slug}', [FProductController::class, 'occasionPage'])->name('pro_occasion');

Route::get('slots', [FrontendController::class, 'getSlots'])->name('getSlots');

Route::post('add-to-cart', [CartController::class, 'addToCart'])->name('add.to.cart');
Route::get('cart', [CartController::class, 'index'])->name('cart');
Route::post('update-cart', [CartController::class, 'updateCart'])->name('update.cart');
Route::get('delete-cart/{id}', [CartController::class, 'deleteCart'])->name('delete.cart');

Route::get('remove-cart-items', [CartController::class, 'removeCartItems'])->name('remove.cart.items');

Route::get('check-coupon/{code}', [CartController::class, 'checkCoupon'])->name('check.coupon');

Route::get('delete-addon-cart/{id}/{addonid}', [CartController::class, 'deleteAddonCart'])->name('delete.addon.cart');
Route::get('checkout', [CartController::class, 'checkout'])->name('checkout')->middleware('auth');
Route::get('pickup', [CartController::class, 'pickup'])->name('pickup');

Route::post('guest-checkout', [CartController::class, 'guestCheckout'])->name('guest.checkout');
Route::get('guest-checkout', [CartController::class, 'guestCheckoutOpen'])->name('open.guest.checkout');

Route::post('payment', [CartController::class, 'payment'])->name('payment');
Route::post('place-order', [CartController::class, 'placeOrder'])->name('place.order');
Route::get('order-confirm/{id}', [CartController::class, 'orderConfirm'])->name('order.confirm');
Route::get('order-cancel/{id}', [CartController::class, 'orderCancel'])->name('order.cancel');
Route::get('order-notify/{id}', [CartController::class, 'orderNotify'])->name('order.notify');

// MISCELLANEOUS
Route::get('about', function () { return view('frontend.about'); })->name('about');
Route::get('contact', function () { return view('frontend.contact'); })->name('contact');
Route::post('contact', [FrontendController::class, 'contact'])->name('contact.store');
Route::get('search/{keyword}', [FrontendController::class, 'search'])->name('search.store');
Route::get('terms-of-delivery', function () { return view('frontend.terms-of-delivery'); })->name('terms-of-delivery');
Route::get('terms-of-sale', function () { return view('frontend.terms-of-sale'); })->name('terms-of-sale');
Route::get('cookies', function () { return view('frontend.cookies'); })->name('cookies');
Route::get('privacy-policy', function () { return view('frontend.privacy-policy'); })->name('privacy-policy');
Route::get('delivery-policy', function () { return view('frontend.delivery-policy'); })->name('delivery-policy');
Route::get('faq', function () { return view('frontend.faq'); })->name('faq');

Route::get('language/{locale}', function ($locale = null) {
    // if (isset($locale) && in_array($locale, config('app.available_locales'))) {
        app()->setLocale($locale);
        session()->put('locale', $locale);
        return redirect()->back();
    // }
    // return redirect()->back();
});

Route::get('/clear', function () {
    Artisan::call('config:cache');
    Artisan::call('route:cache');
    Artisan::call('cache:clear');
    Artisan::call('view:clear');
    return 'Config cache has clear successfully !';
});